@@ -1,7 +1,7 @@
 /******************************************************************************
  * Simple example of how to retrieve an entry from a SWORD module
  *
- * $Id: lookup.cpp 2327 2009-04-22 11:42:33Z scribe $
+ * $Id: lookup.cpp 2546 2010-09-08 14:14:37Z scribe $
  *
  * Copyright 1998-2009 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -25,6 +25,7 @@
 #include <swmgr.h>
 #include <swmodule.h>
 #include <markupfiltmgr.h>
+#include <versekey.h>
 
 using sword::SWMgr;
 using sword::MarkupFilterMgr;
@@ -36,6 +37,7 @@ using sword::ModMap;
 using sword::AttributeTypeList;
 using sword::AttributeList;
 using sword::AttributeValue;
+using sword::VerseKey;
 
 int main(int argc, char **argv)
 {
@@ -67,7 +69,16 @@ int main(int argc, char **argv)
 	manager.setGlobalOption("Lemmas", "Off");
 //	manager.setGlobalOption("Greek Accents", "Off");
 
-	target->setKey(argv[2]);
+	VerseKey *vk = dynamic_cast<VerseKey *>(target->getKey());
+
+	if (vk) {
+	//	vk->AutoNormalize(false);
+		vk->Headings(true);
+		vk->setText(argv[2]);
+	}
+	else {
+		target->setKey(argv[2]);
+	}
 
 	target->RenderText();		// force an entry lookup to resolve key to something in the index
 
