@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Id: cipherfil.h 1688 2005-01-01 04:42:26Z scribe $
+ * $Id: cipherfil.h 1864 2005-11-20 06:06:40Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -22,10 +22,11 @@
 #define CIPHERFIL_H
 
 #include <swfilter.h>
-#include <swcipher.h>
 
 SWORD_NAMESPACE_START
 
+class SWCipher;
+
 class SWDLLEXPORT CipherFilter:public SWFilter {
 	SWCipher *cipher;
 public:
