@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * $Id: gbfhtmlhref.h,v 1.7 2003/08/12 05:36:30 scribe Exp $
+ * $Id: gbfhtmlhref.h 1688 2005-01-01 04:42:26Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -31,8 +31,9 @@ class SWDLLEXPORT GBFHTMLHREF : public SWBasicFilter {
 protected:
 	class MyUserData : public BasicFilterUserData {
 	public:
-		MyUserData(const SWModule *module, const SWKey *key) : BasicFilterUserData(module, key) {}
+		MyUserData(const SWModule *module, const SWKey *key);
 		bool hasFootnotePreTag;
+		SWBuf version;
 	};
 	virtual BasicFilterUserData *createUserData(const SWModule *module, const SWKey *key) {
 		return new MyUserData(module, key);
