@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Id: gbfosis.h,v 1.10 2003/07/05 04:58:42 scribe Exp $
+ * $Id: gbfosis.h 1864 2005-11-20 06:06:40Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -23,11 +23,12 @@
 
 #include <swfilter.h>
 #include <stack>
+#include <swbuf.h>
 
 SWORD_NAMESPACE_START
 
 
-class QuoteStack {
+class SWDLLEXPORT QuoteStack {
 private:
 	class QuoteInstance {
 	public:
@@ -57,8 +58,6 @@ public:
 /** this filter converts GBF text to OSIS text
  */
 class SWDLLEXPORT GBFOSIS : public SWFilter {
-protected:
-	virtual const char *convertToOSIS(const char *, const SWKey *key);
 public:
 	GBFOSIS();
 	virtual ~GBFOSIS();
