@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Id: greeklexattribs.h 1688 2005-01-01 04:42:26Z scribe $
+ * $Id: greeklexattribs.h 1864 2005-11-20 06:06:40Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -21,13 +21,13 @@
 #ifndef GREEKLEXATTRIBS_H
 #define GREEKLEXATTRIBS_H
 
-#include <swfilter.h>
+#include <swoptfilter.h>
 
 SWORD_NAMESPACE_START
 
 /** this filter converts ThML text to plain text
  */
-class SWDLLEXPORT GreekLexAttribs : public SWFilter {
+class SWDLLEXPORT GreekLexAttribs : public SWOptionFilter {
 public:
 	GreekLexAttribs();
 	virtual char processText(SWBuf &text, const SWKey *key = 0, const SWModule *module = 0);
