@@ -4,7 +4,7 @@
  *				(e.g. verse, word,
  *				place, etc.)
  *
- * $Id: listkey.h 1958 2006-08-22 00:15:10Z scribe $
+ * $Id: listkey.h 2195 2008-09-11 00:20:58Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -117,15 +117,16 @@ public:
 	
 	/** Decrements a number of elements
 	 */
-	virtual void decrement(int step);
+	virtual void decrement(int step = 1);
 	
 	/** Increments a number of elements
 	 */
-	virtual void increment(int step);
+	virtual void increment(int step = 1);
 
 	virtual bool isTraversable() const { return true; }
 	virtual long Index() const { return arraypos; }
 	virtual const char *getRangeText() const;
+	virtual const char *getOSISRefRangeText() const;
 
 	/**
 	 * Returns the index for the new one given as as parameter.
