@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * $Id: osishtmlhref.h 2391 2009-05-08 02:02:16Z chrislit $
+ * $Id: osishtmlhref.h 2569 2010-10-14 14:13:34Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -32,17 +32,18 @@ private:
 	bool morphFirst;
 protected:
 	// used by derived classes so we have it in the header
-	class QuoteStack;
+	class TagStacks;
 	class SWDLLEXPORT MyUserData : public BasicFilterUserData {
 	public:
 		bool osisQToTick;
-		bool inBold;
+		bool inBold;	// TODO: obsolete. left for binary compat for 1.6.x
 		bool inXRefNote;
 		bool BiblicalText;
 		int suspendLevel;
 		SWBuf wordsOfChristStart;
 		SWBuf wordsOfChristEnd;
-                QuoteStack *quoteStack;
+                TagStacks *tagStacks;	// TODO: modified to wrap all TagStacks necessary for this filter until 1.7.x
+//                TagStack *hiStack;	// TODO: commented out for binary compat for 1.6.x	 wrapped in tagStacks until 1.7.x
 		SWBuf lastTransChange;
 		SWBuf w;
 		SWBuf fn;
