@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * $Id: osisplain.h 1688 2005-01-01 04:42:26Z scribe $
+ * $Id: osisplain.h 2187 2008-07-22 11:00:16Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -31,15 +31,7 @@ SWORD_NAMESPACE_START
 class SWDLLEXPORT OSISPlain : public SWBasicFilter {
 public:
 protected:
-	class MyUserData : public BasicFilterUserData {
-	public:
-		SWBuf w;
-		XMLTag tag;
-		MyUserData(const SWModule *module, const SWKey *key) : BasicFilterUserData(module, key) {}
-	};
-	virtual BasicFilterUserData *createUserData(const SWModule *module, const SWKey *key) {
-		return new MyUserData(module, key);
-	}
+	virtual BasicFilterUserData *createUserData(const SWModule *module, const SWKey *key);
 	virtual bool handleToken(SWBuf &buf, const char *token, BasicFilterUserData *userData);
 public:
 	OSISPlain();
