@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * $Id: osisrtf.h 1688 2005-01-01 04:42:26Z scribe $
+ * $Id: osisrtf.h 1973 2006-09-20 04:09:16Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -31,19 +31,9 @@ class SWDLLEXPORT OSISRTF : public SWBasicFilter {
 private:
 
 protected:
-	class MyUserData : public BasicFilterUserData {
-	public:
-		bool osisQToTick;
-		bool BiblicalText;
-		bool inXRefNote;
-		SWBuf w;
-		SWBuf version;
-		MyUserData(const SWModule *module, const SWKey *key);
-	};
-	virtual BasicFilterUserData *createUserData(const SWModule *module, const SWKey *key) {
-		return new MyUserData(module, key);
-	}
+	virtual BasicFilterUserData *createUserData(const SWModule *module, const SWKey *key);
 	virtual bool handleToken(SWBuf &buf, const char *token, BasicFilterUserData *userData);
+	virtual char processText(SWBuf &text, const SWKey *key = 0, const SWModule *module = 0);
 public:
 	OSISRTF();
 };
