@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * $Id: osiswebif.h,v 1.1 2003/10/24 02:43:46 scribe Exp $
+ * $Id: osiswebif.h 1946 2006-07-15 20:41:24Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -30,11 +30,14 @@ SWORD_NAMESPACE_START
 class SWDLLEXPORT OSISWEBIF : public OSISHTMLHREF {
 	const SWBuf baseURL;
 	const SWBuf passageStudyURL;
+	bool javascript;
 
 protected:
 	virtual bool handleToken(SWBuf &buf, const char *token, BasicFilterUserData *userData);
+	virtual BasicFilterUserData *createUserData(const SWModule *module, const SWKey *key);
 public:
 	OSISWEBIF();
+	void setJavascript(bool mode) { javascript = mode; }
 };
 
 SWORD_NAMESPACE_END
