@@ -2,7 +2,7 @@
  *  rawcom.h   - code for class 'RawCom'- a module that reads raw commentary
  *			files:	ot and nt using indexs ??.bks ??.cps ??.vss
  *
- * $Id: rawcom.h 1864 2005-11-20 06:06:40Z scribe $
+ * $Id: rawcom.h 2303 2009-04-06 13:38:34Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -36,24 +36,28 @@ class SWDLLEXPORT RawCom : public RawVerse, public SWCom {
 public:
     
 	RawCom(const char *ipath, const char *iname = 0, const char *idesc = 0,
-			SWDisplay * idisp = 0, SWTextEncoding encoding = ENC_UNKNOWN,
+			SWDisplay *idisp = 0, SWTextEncoding encoding = ENC_UNKNOWN,
 			SWTextDirection dir = DIRECTION_LTR, SWTextMarkup markup = FMT_UNKNOWN,
-			const char* ilang = 0);
+			const char *ilang = 0, const char *versification = "KJV");
 	virtual ~RawCom();
 
 	virtual SWBuf &getRawEntryBuf();
 
-	virtual void increment(int steps);
-	virtual void decrement(int steps) { increment(-steps); }
+	virtual void increment(int steps = 1);
+	virtual void decrement(int steps = 1) { increment(-steps); }
 
 	// write interface ----------------------------
 	virtual bool isWritable();
-	static char createModule(const char *path) { return RawVerse::createModule(path); }
+	static char createModule(const char *path, const char *v11n = "KJV") { return RawVerse::createModule(path, v11n); }
 	virtual void setEntry(const char *inbuf, long len = -1);	// Modify current module entry
 	virtual void linkEntry(const SWKey *linkKey);	// Link current module entry to other module entry
 	virtual void deleteEntry();	// Delete current module entry
 	// end write interface ------------------------
 
+	virtual bool isLinked(const SWKey *k1, const SWKey *k2) const;
+	virtual bool hasEntry(const SWKey *k) const;
+
+
 	SWMODULE_OPERATORS
 
 };
