@@ -4,7 +4,7 @@
  *			and provides lookup and parsing functions based on
  *			class StrKey
  *
- * $Id: rawstr4.h 1864 2005-11-20 06:06:40Z scribe $
+ * $Id: rawstr4.h 2303 2009-04-06 13:38:34Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -26,6 +26,7 @@
 #define RAWSTR4_H
 
 #include <defs.h>
+#include <sysdata.h>
 
 SWORD_NAMESPACE_START
 
@@ -35,23 +36,23 @@ class SWBuf;
 class SWDLLEXPORT RawStr4 {
 	static int instance;		// number of instantiated RawStr4 objects or derivitives
 	char *path;
-	long lastoff;
+	mutable long lastoff;		// for caching and optimizations
 
 protected:
+	static const int IDXENTRYSIZE;
+	
 	FileDesc *idxfd;
 	FileDesc *datfd;
-	void prepText(SWBuf &buf);
 	void doSetText(const char *key, const char *buf, long len = -1);
 	void doLinkEntry(const char *destkey, const char *srckey);
 public:
 	char nl;
 	RawStr4(const char *ipath, int fileMode = -1);
 	virtual ~RawStr4();
-	void getIDXBuf(long ioffset, char **buf);
-	void getIDXBufDat(long ioffset, char **buf);
-	signed char findOffset(const char *key, long *start, unsigned long *size,
-	long away = 0, long *idxoff = 0);
-	void readText(long start, unsigned long *size, char **idxbuf, SWBuf &buf);
+	void getIDXBuf(long ioffset, char **buf) const;
+	void getIDXBufDat(long ioffset, char **buf) const;
+	signed char findOffset(const char *key, __u32 *start, __u32 *size, long away = 0, __u32 *idxoff = 0) const;
+	void readText(__u32 start, __u32 *size, char **idxbuf, SWBuf &buf);
 	static signed char createModule(const char *path);
 };
 
