@@ -8,22 +8,23 @@
 #ifndef RAWVERSE_H
 #define RAWVERSE_H
 
-#include <filemgr.h>
-#include <fcntl.h>
 
 #include <defs.h>
-#include <swbuf.h>
 
 SWORD_NAMESPACE_START
 
+class FileDesc;
+class SWBuf;
+
 class SWDLLEXPORT RawVerse {
+
+
 	static int instance;		// number of instantiated RawVerse objects or derivitives
 protected:
 	FileDesc *idxfp[2];
 	FileDesc *textfp[2];
 
 	char *path;
-	void prepText(SWBuf &buf);
 	void doSetText(char testmt, long idxoff, const char *buf, long len = -1);
 	void doLinkEntry(char testmt, long destidxoff, long srcidxoff);
 
@@ -31,9 +32,9 @@ public:
 	static const char *nl;
 	RawVerse(const char *ipath, int fileMode = -1);
 	virtual ~RawVerse();
-	void findOffset(char testmt, long idxoff, long *start,	unsigned short *end);
+	void findOffset(char testmt, long idxoff, long *start,	unsigned short *end) const;
 	void readText(char testmt, long start, unsigned short size, SWBuf &buf);
-	static char createModule(const char *path);
+	static char createModule(const char *path, const char *v11n = "KJV");
 };
 
 SWORD_NAMESPACE_END
