@@ -25,7 +25,6 @@ protected:
 	FileDesc *textfp[2];
 
 	char *path;
-	void prepText(SWBuf &buf);
 	void doSetText(char testmt, long idxoff, const char *buf, long len = -1);
 	void doLinkEntry(char testmt, long destidxoff, long srcidxoff);
 
@@ -33,9 +32,9 @@ public:
 	static const char *nl;
 	RawVerse4(const char *ipath, int fileMode = -1);
 	virtual ~RawVerse4();
-	void findOffset(char testmt, long idxoff, long *start,	unsigned long *end);
+	void findOffset(char testmt, long idxoff, long *start,	unsigned long *end) const;
 	void readText(char testmt, long start, unsigned long size, SWBuf &buf);
-	static char createModule(const char *path);
+	static char createModule(const char *path, const char *v11n = "KJV");
 };
 
 SWORD_NAMESPACE_END
