@@ -4,7 +4,7 @@
  *  				many filter will need and can use as a starting
  *  				point. 
  *
- * $Id: swbasicfilter.h 1864 2005-11-20 06:06:40Z scribe $
+ * $Id: swbasicfilter.h 1984 2006-10-08 05:06:52Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -39,6 +39,7 @@ public:
 	const SWModule *module;
 	const SWKey *key;
 	SWBuf lastTextNode;
+	SWBuf lastSuspendSegment;
 	bool suspendTextPassThru;
 	bool supressAdjacentWhitespace;
 };
@@ -70,6 +71,7 @@ class Private;
 	bool tokenCaseSensitive;
 	bool passThruUnknownToken;
 	bool passThruUnknownEsc;
+	bool passThruNumericEsc;
 	char processStages;
 
 
@@ -116,14 +118,28 @@ protected:
 	 */
 	void setPassThruUnknownEscapeString(bool val);
 
+	/** Sets whether to pass thru a numeric escape sequence unchanged
+	 *	or allow it to be handled otherwise.
+	 * Default is false.*/
+	void setPassThruNumericEscapeString(bool val);
+
 	/** Are escapeStrings case sensitive or not? Call this
 	 *	function before addEscapeStingSubstitute()
 	 */
 	void setEscapeStringCaseSensitive(bool val);
 
+	/** Registers an esc control sequence that can pass unchanged
+	 */
+	void addAllowedEscapeString(const char *findString);
+
+	/** Unregisters an esc control sequence that can pass unchanged
+	 */
+	void removeAllowedEscapeString(const char *findString);
+
 	/** Registers an esc control sequence
 	 */
 	void addEscapeStringSubstitute(const char *findString, const char *replaceString);
+
 	/** Unregisters an esc control sequence
 	 */
 	void removeEscapeStringSubstitute(const char *findString);
@@ -131,6 +147,12 @@ protected:
 	/** This function performs the substitution of escapeStrings */
 	bool substituteEscapeString(SWBuf &buf, const char *escString);
 
+	/** This passes allowed escapeStrings */
+	bool passAllowedEscapeString(SWBuf &buf, const char *escString);
+
+	/** This appends escString to buf as an entity */
+	void appendEscapeString(SWBuf &buf, const char *escString);
+
 	/** Are tokens case sensitive (like in GBF) or not? Call this
 	 *	function before addTokenSubstitute()
 	 */
@@ -168,6 +190,14 @@ protected:
 	 */
 	virtual bool handleEscapeString(SWBuf &buf, const char *escString, BasicFilterUserData *userData);
 
+	/** This function is called for all numeric escape sequences. If passThrough
+	 * @param buf the output buffer 
+	 * @param escString the escape sequence (e.g. <code>"#235"</code> for &amp;235;)
+	 * @return subclasses should return true if they handled the esc seq, or false if they did not.
+         */
+	virtual bool handleNumericEscapeString(SWBuf &buf, const char *escString);
+
+
 };
 
 SWORD_NAMESPACE_END
