@@ -1,7 +1,7 @@
 /******************************************************************************
 *  swbuf.h  - code for SWBuf used as a transport and utility for data buffers
 *
-* $Id: swbuf.h 1960 2006-08-28 08:14:40Z scribe $
+* $Id: swbuf.h 2378 2009-05-04 23:18:51Z scribe $
 *
 * Copyright 2003 CrossWire Bible Society (http://www.crosswire.org)
 *	CrossWire Bible Society
@@ -32,7 +32,7 @@
 SWORD_NAMESPACE_START
 
 
-#define JUNKBUFSIZE 8191
+#define JUNKBUFSIZE 65534
 
 /**
 * This class is used as a transport and utility for data buffers.
@@ -151,9 +151,15 @@ public:
 	*/
 	inline unsigned long size() const { return length(); }
 
+	/** 
+	 * set's the size of the buffer.  This is a quick inline method which checks
+	 * for changes before actually calling setSize().
+	 * @param newSize new size of the buffer
+	 */
+	inline void size(unsigned long newSize) { if (end - buf - newSize) setSize(newSize); }
+
 	/**
 	* @return size() and length() return only the number of characters of the string.
-	* Add one for the following null and one for each char to be appended!
 	*/
 	inline unsigned long length() const { return end - buf; }
 
@@ -207,7 +213,7 @@ public:
 	* @param format The format string. Same syntax as printf, for example.
 	* @param ... Add all arguments here.
 	*/
-	void setFormatted(const char *format, ...);
+	SWBuf &setFormatted(const char *format, ...);
 
 	/**
 	* SWBuf::setSize - Size this buffer to a specific length.
@@ -311,41 +317,117 @@ public:
 	inline SWBuf &operator =(const SWBuf &other) { set(other); return *this; }
 	inline SWBuf &operator +=(const char *str) { append(str); return *this; }
 	inline SWBuf &operator +=(char ch) { append(ch); return *this; }
+
+	/**
+	 * Decrease the buffer size, discarding the last characters
+	 * @param len how many bytes to decrease the buffer size
+	 */
 	inline SWBuf &operator -=(unsigned long len) { setSize(length()-len); return *this; }
+
+	/**
+	 * Decrease the buffer size, discarding the last character
+	 */
 	inline SWBuf &operator --(int) { operator -=(1); return *this; }
 
-	inline SWBuf &operator <<(unsigned long n) { n = (n<length())?n:(length()-1); memmove(buf, buf+n, length()-n); (*this)-=n; return *this; }
+	/**
+	 * Shift the buffer to the left, discarding the first bytes, decreasing the buffer size
+	 */
+	inline SWBuf &operator <<(unsigned long n) { if (n && length()) { n = (n<=length())?n:(length()-1); memmove(buf, buf+n, length()-n); (*this)-=n; } return *this; }
+
+	/**
+	 * Shift the buffer to the right, increasing the buffer size
+	 */
 	inline SWBuf &operator >>(unsigned long n) { setSize(length()+n); memmove(buf+n, buf, length()-n); return *this; }
+
+	/**
+	 * Concatenate another buffer to the end of this buffer
+	 */
 	inline SWBuf operator +(const SWBuf &other) const {
 		SWBuf retVal = buf;
 		retVal += other;
 		return retVal;
 	}
+
+	/**
+	 * Concatenate a byte to the end of this buffer
+	 */
 	inline SWBuf operator +(char ch) const { return (*this) + SWBuf(ch); }
 
+	/**
+	 * Trim whitespace from the start of this buffer, shifting the buffer left as necessary
+	 */
 	inline SWBuf &trimStart() { while (size() && (strchr("\t\r\n ", *(buf)))) *this << 1; return *this; }
+
+	/**
+	 * Trim whitespace from the end of this buffer, decreasing the size as necessary
+	 */
 	inline SWBuf &trimEnd() { while (size() && (strchr("\t\r\n ", *(end-1)))) setSize(size()-1); return *this; }
+
+	/**
+	 * Trim whitespace from the start and end of this buffer, shifting left and decreasing size as necessary
+	 */
 	inline SWBuf &trim() { trimStart(); return trimEnd(); }
 
+
+	/**
+	 * Strip a prefix from this buffer up to a separator byte.
+	 * Returns the prefix and modifies this buffer, shifting left to remove prefix
+	 * @param separator to use (e.g. ':')
+	 * @param endOfStringAsSeparator - also count end of string as separator.
+	 *                                 this is useful for tokenizing entire string like:
+	 *                                 x|y|z
+	 *                                 if true it will also include 'z'.
+	 *
+	 * @return prefix if separator character found; otherwise, null and leaves buffer unmodified
+	 */
+	inline const char *stripPrefix(char separator, bool endOfStringAsSeparator = false) { const char *m = strchr(buf, separator); if (!m && endOfStringAsSeparator) { if (*buf) { operator >>(1); *buf=0; end = buf; return buf + 1;} else return buf; } if (m) { int len = m-buf; char *hold = new char[len]; memcpy(hold, buf, len); *this << (len+1); memcpy(end+1, hold, len); delete [] hold; end[len+1] = 0; } return (m) ? end+1 : 0; }  // safe.  we know we don't actually realloc and shrink buffer when shifting, so we can place our return val at end.
+
+	// this could be nicer, like replacing a contiguous series of target bytes with single replacement; offering replacement const char *
+	/**
+	 * Replace with a new byte value all occurances in this buffer of any byte value specified in a set
+	 * @param targets a set of bytes, any of which will be replaced
+	 * @param newByte value to use as replacement.
+	 *
+	 * Example: replaceBytes("abc", 'z');  // replaces all occurances of 'a', 'b', and 'c' with 'z'
+	 */
+	inline SWBuf &replaceBytes(const char *targets, char newByte) { for (unsigned int i = 0; (i < size()); i++) { if (strchr(targets, buf[i])) buf[i] = newByte; } return *this; }
+
+	/**
+	 * @return returns true if this buffer starts with the specified prefix
+	 */
 	inline bool startsWith(const SWBuf &prefix) const { return !strncmp(c_str(), prefix.c_str(), prefix.size()); }
+
+	/**
+	 * @return returns true if this buffer ends with the specified postfix
+	 */
 	inline bool endsWith(const SWBuf &postfix) const { return (size() >= postfix.size())?!strncmp(end-postfix.size(), postfix.c_str(), postfix.size()):false; }
+
 	inline int compare(const SWBuf &other) const { return strcmp(c_str(), other.c_str()); }
-	inline bool operator ==(const SWBuf &other) const { return !compare(other); }
-	inline bool operator !=(const SWBuf &other) const { return compare(other); }
+	inline bool operator ==(const SWBuf &other) const { return compare(other) == 0; }
+	inline bool operator !=(const SWBuf &other) const { return compare(other) != 0; }
 	inline bool operator > (const SWBuf &other) const { return compare(other) > 0; }
 	inline bool operator < (const SWBuf &other) const { return compare(other) < 0; }
 	inline bool operator <=(const SWBuf &other) const { return compare(other) <= 0; }
 	inline bool operator >=(const SWBuf &other) const { return compare(other) >= 0; }
 
+	/**
+	 * @return returns true if this buffer starts with the specified prefix
+	 */
 	inline bool startsWith(const char *prefix) const { return !strncmp(c_str(), prefix, strlen(prefix)); }
-	inline bool endsWith(const char *postfix) const { int psize = strlen(postfix); return (size() >= psize)?!strncmp(end-psize, postfix, psize):false; }
-	inline int compare(const char *other) const { return strcmp(c_str(), other); }
-	inline bool operator ==(const char *other) const { return !compare(other); }
-	inline bool operator !=(const char *other) const { return compare(other); }
-	inline bool operator > (const char *other) const { return compare(other) > 0; }
-	inline bool operator < (const char *other) const { return compare(other) < 0; }
-	inline bool operator <=(const char *other) const { return compare(other) <= 0; }
-	inline bool operator >=(const char *other) const { return compare(other) >= 0; }
+
+	/**
+	 * @return returns true if this buffer ends with the specified postfix
+	 */
+	inline bool endsWith(const char *postfix) const { unsigned int psize = strlen(postfix); return (size() >= psize)?!strncmp(end-psize, postfix, psize):false; }
+
+	// be sure we've been given a valid pointer to compare.  If not, we return !=; specifically less-than, for lack of better options
+	inline int compare(const char *other) const { return (other?strcmp(c_str(), other):-1); }
+	inline bool operator ==(const char *other) const { return compare(other) == 0; }
+	inline bool operator !=(const char *other) const { return compare(other) != 0; }
+	inline bool operator > (const char *other) const { return other && compare(other) > 0; }
+	inline bool operator < (const char *other) const { return other && compare(other) < 0; }
+	inline bool operator <=(const char *other) const { return other && compare(other) <= 0; }
+	inline bool operator >=(const char *other) const { return other && compare(other) >= 0; }
 };
 
 
