@@ -1,7 +1,7 @@
 /******************************************************************************
  *  swcipher.h   - definition of Class SWCipher used for data cipher/decipher
  *
- * $Id: swcipher.h 1688 2005-01-01 04:42:26Z scribe $
+ * $Id: swcipher.h 1864 2005-11-20 06:06:40Z scribe $
  *
  * Copyright 1999 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -22,7 +22,7 @@
 #ifndef SWCIPHER_H
 #define SWCIPHER_H
 
-#include "sapphire.h"
+#include <sapphire.h>
 
 #include <defs.h>
 
