@@ -2,7 +2,7 @@
  *  swtext.h   - code for base class 'SWText'.  SWText is the basis for all
  *		 types of text modules
  *
- * $Id: swtext.h 1864 2005-11-20 06:06:40Z scribe $
+ * $Id: swtext.h 2324 2009-04-20 18:40:15Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -36,24 +36,28 @@ class VerseKey;
 class SWDLLEXPORT SWText : public SWModule {
 
 	// for conversion if we have been set with a different internal key type
-	mutable VerseKey *tmpVK;
+	mutable VerseKey *tmpVK1;
+	mutable VerseKey *tmpVK2;
+        mutable bool tmpSecond;
+	char *versification;
 
 protected:
-	VerseKey &getVerseKey() const;
+	VerseKey &getVerseKey(const SWKey* key=0) const;
 	
 public:
 	/** Initializes data for instance of SWText
 	*/
 	SWText(const char *imodname = 0, const char *imoddesc = 0,
-			SWDisplay * idisp = 0,
+			SWDisplay *idisp = 0,
 			SWTextEncoding encoding = ENC_UNKNOWN,
 			SWTextDirection dir = DIRECTION_LTR,
-			SWTextMarkup markup = FMT_UNKNOWN, const char* ilang = 0);
+			SWTextMarkup markup = FMT_UNKNOWN, const char *ilang = 0,
+			const char *versification = "KJV");
 
 	virtual ~SWText();
 	/** Create the correct key (VerseKey) for use with SWText
 	*/
-	virtual SWKey *CreateKey();
+	virtual SWKey *CreateKey() const;
 
 	virtual long Index() const;
 	virtual long Index(long iindex);
