@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * $Id: thmlvariants.h 1688 2005-01-01 04:42:26Z scribe $
+ * $Id: thmlvariants.h 1864 2005-11-20 06:06:40Z scribe $
  *
  * Copyright 2001 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -21,14 +21,13 @@
 #ifndef THMLVARIANTS_H
 #define THMLVARIANTS_H
 
-#include <swfilter.h>
-#include <swmodule.h>
+#include <swoptfilter.h>
 
 SWORD_NAMESPACE_START
 
 /** This Filter shows/hides textual variants
  */
-class SWDLLEXPORT ThMLVariants : public SWFilter {
+class SWDLLEXPORT ThMLVariants : public SWOptionFilter {
 	char option;
 
 	static const char primary[];
