@@ -1,7 +1,7 @@
 /******************************************************************************
  *  versekey.h - code for class 'versekey'- a standard Biblical verse key
  *
- * $Id: treekey.h 1958 2006-08-22 00:15:10Z scribe $
+ * $Id: treekey.h 2280 2009-03-07 15:34:36Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -44,7 +44,24 @@ protected:
 	// This better conforms to the SWORD write methodology: mod.setKey, mod.setEntry
 	mutable SWBuf unsnappedKeyText;
 
+	// called whenever position of this key is changed.  Should we move this
+	// to a more base class?
+	void positionChanged() { if (posChangeListener) posChangeListener->positionChanged(); }
+
 public:
+
+	class PositionChangeListener {
+		TreeKey *treeKey;
+	public:
+		PositionChangeListener() {}
+		virtual ~PositionChangeListener() {}
+		virtual void positionChanged() = 0;
+		TreeKey *getTreeKey() { return treeKey; }
+		void setTreeKey(TreeKey *tk) { treeKey = tk; }
+	} *posChangeListener;
+
+	void setPositionChangeListener(PositionChangeListener *pcl) { posChangeListener = pcl; posChangeListener->setTreeKey(this); }
+
 //	TreeKey (const char *ikey = 0);
 //	TreeKey (const SWKey * ikey);
 //	TreeKey (TreeKey const &k);
@@ -55,7 +72,9 @@ public:
 	virtual const char *getLocalName() = 0;
 	virtual const char *setLocalName(const char *) = 0;
 
-	virtual const char *getUserData(int *size = 0) = 0;
+	virtual int getLevel() { long bm = getOffset(); int level = 0; do { level++; } while (parent()); setOffset(bm); return level; }
+
+	virtual const char *getUserData(int *size = 0) const = 0;
 	virtual void setUserData(const char *userData, int size = 0) = 0;
 
 	/** Go to the root node
@@ -109,7 +128,7 @@ public:
 
 	/** Set the key to this path.  If the path doesn't exist, then
 	 *	nodes are created as necessary
-	 * @keyPath = path to set/create; if unsupplied, then use any unsnapped setText value.
+	 * @param keyPath path to set/create; if unsupplied, then use any unsnapped setText value.
 	 */
 	virtual void assureKeyPath(const char *keyPath = 0);
 	virtual void save() {}
