@@ -1,7 +1,7 @@
 /******************************************************************************
  *  versekey.h - code for class 'versekey'- a standard Biblical verse key
  *
- * $Id: treekeyidx.h 1958 2006-08-22 00:15:10Z scribe $
+ * $Id: treekeyidx.h 2280 2009-03-07 15:34:36Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -35,13 +35,13 @@ class FileDesc;
  * The TreeKey implementation used for all tree-based modules in Sword, such as GenBooks.
  */
 class SWDLLEXPORT TreeKeyIdx : public TreeKey {
-
+		
 	class TreeNode {
 	public:
 		TreeNode();
 		~TreeNode();
 		void clear();
-		__u32 offset;
+		__s32 offset;
 		__s32 parent;
 		__s32 next;
 		__s32 firstChild;
@@ -57,23 +57,25 @@ class SWDLLEXPORT TreeKeyIdx : public TreeKey {
 	FileDesc *idxfd;
 	FileDesc *datfd;
 
+	void init();
+
 	void getTreeNodeFromDatOffset(long ioffset, TreeNode *buf) const;
 	char getTreeNodeFromIdxOffset(long ioffset, TreeNode *node) const;
 	void saveTreeNode(TreeNode *node);
 	void saveTreeNodeOffsets(TreeNode *node);
-	void init();
+
 
 public:
 	TreeKeyIdx(const TreeKeyIdx &ikey);
-	TreeKeyIdx (const char *idxPath, int fileMode = -1);
-	~TreeKeyIdx ();
+	TreeKeyIdx(const char *idxPath, int fileMode = -1);
+	virtual ~TreeKeyIdx();
 
 	virtual SWKey *clone() const;
 
 	virtual const char *getLocalName();
 	virtual const char *setLocalName(const char *);
 
-	virtual const char *getUserData(int *size = 0);
+	virtual const char *getUserData(int *size = 0) const;
 	virtual void setUserData(const char *userData, int size = 0);
 
 	virtual void root();
@@ -98,6 +100,8 @@ public:
 	void setOffset(unsigned long offset);
 	unsigned long getOffset() const;
 
+	virtual int getLevel();
+
 
 	// OPERATORS ------------------------------------------------------------
 
