@@ -2,7 +2,7 @@
  *  zcom.h   - code for class 'zCom'- a module that reads compressed text
  *				files: ot and nt using indexs ??.vss
  *
- * $Id: zcom.h 1864 2005-11-20 06:06:40Z scribe $
+ * $Id: zcom.h 2303 2009-04-06 13:38:34Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -39,10 +39,11 @@ class SWDLLEXPORT zCom : public zVerse, public SWCom {
 public:
 
 	zCom(const char *ipath, const char *iname = 0, const char *idesc = 0,
-			int blockType = CHAPTERBLOCKS, SWCompress * icomp = 0,
-			SWDisplay * idisp = 0, SWTextEncoding encoding = ENC_UNKNOWN,
+			int blockType = CHAPTERBLOCKS, SWCompress *icomp = 0,
+			SWDisplay *idisp = 0, SWTextEncoding encoding = ENC_UNKNOWN,
 			SWTextDirection dir = DIRECTION_LTR,
-			SWTextMarkup markup = FMT_UNKNOWN, const char* ilang = 0);
+			SWTextMarkup markup = FMT_UNKNOWN, const char *ilang = 0,
+			const char *versification = "KJV");
 	virtual ~zCom();
 	virtual SWBuf &getRawEntryBuf();
 	virtual void increment(int steps = 1);
@@ -50,8 +51,8 @@ public:
 
 	// write interface ----------------------------
 	virtual bool isWritable();
-	static char createModule(const char *path, int blockBound) {
-		return zVerse::createModule(path, blockBound);
+	static char createModule(const char *path, int blockBound, const char *v11n = "KJV") {
+		return zVerse::createModule(path, blockBound, v11n);
 	}
 	virtual void setEntry(const char *inbuf, long len = -1);	// Modify current module entry
 	virtual void linkEntry(const SWKey * linkKey);	// Link current module entry to other module entry
@@ -64,6 +65,9 @@ public:
 	virtual void flush() { flushCache(); }
 	// end swcacher interface ----------------------
 
+	virtual bool isLinked(const SWKey *k1, const SWKey *k2) const;
+	virtual bool hasEntry(const SWKey *k) const;
+	
 	SWMODULE_OPERATORS
 
 };
