@@ -1,7 +1,7 @@
 /******************************************************************************
  *  swcomprs.h   - definition of Class SWCompress used for data compression
  *
- * $Id: zipcomprs.h 1688 2005-01-01 04:42:26Z scribe $
+ * $Id: zipcomprs.h 1864 2005-11-20 06:06:40Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -28,14 +28,15 @@
 
 SWORD_NAMESPACE_START
 
-class SWDLLEXPORT ZipCompress:public SWCompress
-{
+class SWDLLEXPORT ZipCompress : public SWCompress {
+
 protected:
 public:
-  ZipCompress ();
-  virtual ~ ZipCompress ();
-  virtual void Encode (void);
-  virtual void Decode (void);
+	ZipCompress();
+	virtual ~ZipCompress();
+
+	virtual void Encode(void);
+	virtual void Decode(void);
 };
 
 SWORD_NAMESPACE_END
