@@ -2,7 +2,7 @@
  *  zld.cpp - code for class 'zLD'- a module that reads compressed lexicon and
  *				dictionary files.
  *
- * $Id: zld.h 1790 2005-05-03 03:49:04Z scribe $
+ * $Id: zld.h 2303 2009-04-06 13:38:34Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -31,8 +31,6 @@
 SWORD_NAMESPACE_START
 
 class SWDLLEXPORT zLD : public zStr, public SWLD {
-
-	void strongsPad(char *buf);
 	char getEntry(long away = 0);
 
 public:
@@ -47,9 +45,7 @@ public:
 	virtual void decrement(int steps = 1) { increment(-steps); }
 
 	// write interface ----------------------------
-	virtual bool isWritable() {
-		return ((idxfd->getFd() > 0) && ((idxfd->mode & FileMgr::RDWR) == FileMgr::RDWR));
-	}
+	virtual bool isWritable();
 	static char createModule(const char *path) {
 		return zStr::createModule(path);
 	}
@@ -65,6 +61,10 @@ public:
 	virtual void flush() { flushCache(); }
 	// end swcacher interface ----------------------
 
+	virtual long getEntryCount() const;
+	virtual long getEntryForKey(const char *key) const;
+	virtual char *getKeyForEntry(long entry) const;
+
 
 	// OPERATORS -----------------------------------------------------------------
 	
