@@ -2,7 +2,7 @@
  *  ztext.h   - code for class 'zText'- a module that reads compressed text
  *				files: ot and nt using indexs ??.vss
  *
- * $Id: ztext.h 1790 2005-05-03 03:49:04Z scribe $
+ * $Id: ztext.h 2303 2009-04-06 13:38:34Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -24,9 +24,7 @@
 #define ZTEXT_H
 
 #include <zverse.h>
-#include <rawstr.h>
 #include <swtext.h>
-//#include <swcomprs.h>
 
 #include <defs.h>
 
@@ -49,16 +47,16 @@ class SWDLLEXPORT zText:public zVerse, public SWText {
 	VerseKey *lastWriteKey;
 	bool sameBlock(VerseKey * lastWriteKey, VerseKey * key);
 	int blockType;
-	VerseKey &getVerseKey();
 
 
 public:
     
 	zText(const char *ipath, const char *iname = 0, const char *idesc = 0,
-			int blockType = CHAPTERBLOCKS, SWCompress * icomp = 0,
-			SWDisplay * idisp = 0, SWTextEncoding encoding = ENC_UNKNOWN,
+			int blockType = CHAPTERBLOCKS, SWCompress *icomp = 0,
+			SWDisplay *idisp = 0, SWTextEncoding encoding = ENC_UNKNOWN,
 			SWTextDirection dir = DIRECTION_LTR,
-			SWTextMarkup markup = FMT_UNKNOWN, const char* ilang = 0);
+			SWTextMarkup markup = FMT_UNKNOWN, const char *ilang = 0,
+			const char *versification = "KJV");
 
 	virtual ~zText();
 	virtual SWBuf &getRawEntryBuf();
@@ -67,9 +65,9 @@ public:
 	virtual void decrement(int steps = 1) { increment(-steps); }
 
   // write interface ----------------------------
-	virtual bool isWritable() { return ((idxfp[0]->getFd() > 0) && ((idxfp[0]->mode & FileMgr::RDWR) == FileMgr::RDWR)); }
-	static char createModule(const char *path, int blockBound) {
-		return zVerse::createModule(path, blockBound);
+	virtual bool isWritable();
+	static char createModule(const char *path, int blockBound, const char *v11n = "KJV") {
+		return zVerse::createModule(path, blockBound, v11n);
 	}
 
      virtual void setEntry(const char *inbuf, long len = -1);	// Modify current module entry
@@ -83,6 +81,9 @@ public:
 	virtual void flush() { flushCache(); }
 	// end swcacher interface ----------------------
 
+	virtual bool isLinked(const SWKey *k1, const SWKey *k2) const;
+	virtual bool hasEntry(const SWKey *k) const;
+	
 	SWMODULE_OPERATORS
 
 };
