@@ -1,9 +1,26 @@
 /******************************************************************************
  *  StrKey.cpp - code for class 'StrKey'- a standard string key class (used
- *				for modules that index on single strings (eg. cities,
- *				names, words, etc.)
+ *		 for modules that index on single strings (eg. cities,
+ *		 names, words, etc.)
+ *
+ *
+ * Copyright 2009 CrossWire Bible Society (http://www.crosswire.org)
+ *	CrossWire Bible Society
+ *	P. O. Box 2528
+ *	Tempe, AZ  85280-2528
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the
+ * Free Software Foundation version 2.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
  */
 
+
 #include <swmacs.h>
 #include <strkey.h>
 #include <stdio.h>
