@@ -563,6 +563,17 @@ ListKey VerseKey::ParseVerseList(const char *buf, const char *defaultKey, bool e
 			}
 
 		case '-':
+			if (chap == -1) {
+				book[tobook] = *buf;
+				book[tobook+1] = *(buf+1);
+				book[tobook+2] = 0;
+				int bookno = getBookAbbrev(book);
+				if (bookno > -1) {
+					tobook++;
+					buf++;
+					break;
+				}
+			}
 		case ',': // on number new verse
 		case ';': // on number new chapter
 			number[tonumber] = 0;
@@ -618,6 +629,9 @@ ListKey VerseKey::ParseVerseList(const char *buf, const char *defaultKey, bool e
 					strcpy(book, lastKey->getBookName());
 				}
 				bookno = getBookAbbrev(book);
+				if ((bookno > -1) && (suffix == 'f') && (book[strlen(book)-1] == 'f')) {
+					suffix = 0;
+				}
 			}
 			if (((bookno > -1) || (!*book)) && ((*book) || (chap >= 0) || (verse >= 0))) {
 				char partial = 0;
@@ -765,6 +779,8 @@ ListKey VerseKey::ParseVerseList(const char *buf, const char *defaultKey, bool e
 		default:
 			if (isdigit(*buf)) {
 				number[tonumber++] = *buf;
+				suffix = 0;
+				doubleF = 0;
 			}
 			else {
 				switch (*buf) {
@@ -843,6 +859,9 @@ ListKey VerseKey::ParseVerseList(const char *buf, const char *defaultKey, bool e
 			strcpy(book, lastKey->getBookName());
 		}
 		bookno = getBookAbbrev(book);
+		if ((bookno > -1) && (suffix == 'f') && (book[strlen(book)-1] == 'f')) {
+			suffix = 0;
+		}
 	}
 	if (((bookno > -1) || (!*book)) && ((*book) || (chap >= 0) || (verse >= 0))) {
 		char partial = 0;
@@ -938,7 +957,7 @@ ListKey VerseKey::ParseVerseList(const char *buf, const char *defaultKey, bool e
 						*curKey = MAXCHAPTER;
 					if (partial > 0)
 						*curKey = MAXVERSE;
-						newElement->UpperBound(*curKey);
+					newElement->UpperBound(*curKey);
 					*newElement = TOP;
 					tmpListKey.GetElement()->userData = (void *)(bufStart+(buf-iBuf.c_str()));
 				}
@@ -966,10 +985,11 @@ VerseKey &VerseKey::LowerBound(const VerseKey &lb)
 	initBounds();
 
 	lowerBound = lb.Index();
-	lowerBoundComponents.test  = lb.getTestament();
-	lowerBoundComponents.book  = lb.getBook();
-	lowerBoundComponents.chap  = lb.getChapter();
-	lowerBoundComponents.verse = lb.getVerse();
+	lowerBoundComponents.test   = lb.getTestament();
+	lowerBoundComponents.book   = lb.getBook();
+	lowerBoundComponents.chap   = lb.getChapter();
+	lowerBoundComponents.verse  = lb.getVerse();
+	lowerBoundComponents.suffix = lb.getSuffix();
 
 	// both this following check and UpperBound check force upperBound to
 	// change allowing LowerBound then UpperBound logic to always flow
@@ -990,10 +1010,11 @@ VerseKey &VerseKey::UpperBound(const VerseKey &ub)
 	initBounds();
 
 	upperBound = ub.Index();
-	upperBoundComponents.test  = ub.getTestament();
-	upperBoundComponents.book  = ub.getBook();
-	upperBoundComponents.chap  = ub.getChapter();
-	upperBoundComponents.verse = ub.getVerse();
+	upperBoundComponents.test   = ub.getTestament();
+	upperBoundComponents.book   = ub.getBook();
+	upperBoundComponents.chap   = ub.getChapter();
+	upperBoundComponents.verse  = ub.getVerse();
+	upperBoundComponents.suffix = ub.getSuffix();
 
 	// see LowerBound comment, above
 	if (upperBound < lowerBound) upperBound = lowerBound;
@@ -1015,6 +1036,7 @@ VerseKey &VerseKey::LowerBound() const
 		tmpClone->book      = lowerBoundComponents.book;
 		tmpClone->chapter   = lowerBoundComponents.chap;
 		tmpClone->setVerse   (lowerBoundComponents.verse);
+		tmpClone->setSuffix  (lowerBoundComponents.suffix);
 	}
 	else tmpClone->Index(lowerBound);
 
@@ -1034,6 +1056,7 @@ VerseKey &VerseKey::UpperBound() const
 		tmpClone->book      = upperBoundComponents.book;
 		tmpClone->chapter   = upperBoundComponents.chap;
 		tmpClone->setVerse   (upperBoundComponents.verse);
+		tmpClone->setSuffix  (upperBoundComponents.suffix);
 	}
 	else tmpClone->Index(upperBound);
 
@@ -1064,16 +1087,18 @@ void VerseKey::initBounds() const
 		tmpClone->Chapter(tmpClone->getChapterMax());
 		tmpClone->Verse(tmpClone->getVerseMax());
 		upperBound = tmpClone->Index();
-		upperBoundComponents.test  = tmpClone->getTestament();
-		upperBoundComponents.book  = tmpClone->getBook();
-		upperBoundComponents.chap  = tmpClone->getChapter();
-		upperBoundComponents.verse = tmpClone->getVerse();
+		upperBoundComponents.test   = tmpClone->getTestament();
+		upperBoundComponents.book   = tmpClone->getBook();
+		upperBoundComponents.chap   = tmpClone->getChapter();
+		upperBoundComponents.verse  = tmpClone->getVerse();
+		upperBoundComponents.suffix = tmpClone->getSuffix();
 
 		lowerBound = 0;
-		lowerBoundComponents.test  = 0;
-		lowerBoundComponents.book  = 0;
-		lowerBoundComponents.chap  = 0;
-		lowerBoundComponents.verse = 0;
+		lowerBoundComponents.test   = 0;
+		lowerBoundComponents.book   = 0;
+		lowerBoundComponents.chap   = 0;
+		lowerBoundComponents.verse  = 0;
+		lowerBoundComponents.suffix = 0;
 
 	}
 	else tmpClone->setLocale(getLocale());
@@ -1403,8 +1428,8 @@ void VerseKey::setTestament(char itestament)
 
 void VerseKey::setBook(char ibook)
 {
-	verse   = ibook ? 1 : 0;
-	chapter = ibook ? 1 : 0;
+	verse   = 1;
+	chapter = 1;
 	book    = ibook;
 	Normalize(1);
 }
@@ -1440,9 +1465,11 @@ void VerseKey::setBookName(const char *bname)
 
 void VerseKey::setChapter(int ichapter)
 {
-	verse   = ichapter ? 1 : 0;
+	verse   = 1;
 	chapter = ichapter;
 	Normalize(1);
+	// TODO: easiest fix, but should be in Normalize
+	verse   = 1;
 }
 
 
