@@ -2,7 +2,7 @@
  *  filemgr.cpp	- implementation of class FileMgr used for pooling file
  *  					handles
  *
- * $Id: filemgr.cpp 2245 2009-02-10 23:22:28Z scribe $
+ * $Id: filemgr.cpp 2495 2009-12-24 22:22:16Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -59,6 +59,15 @@
 #endif
 // -----------
 
+// ------- if we still don't have something
+#ifndef S_IREAD
+#define S_IREAD 0400
+#endif
+#ifndef S_IWRITE
+#define S_IWRITE 0200
+#endif
+// -------
+
 
 SWORD_NAMESPACE_START
 
@@ -273,20 +282,23 @@ signed char FileMgr::trunc(FileDesc *file) {
 		file->seek(0, SEEK_SET);
 		while (size > 0) {	 
 			bytes = file->read(nibble, 32767);
-			write(fd, nibble, (bytes < size)?bytes:size);
+			bytes = (bytes < size)?bytes:size;
+			if (write(fd, nibble, bytes) != bytes) { break; }
 			size -= bytes;
 		}
-		// zero out the file
-		::close(file->fd);
-		file->fd = ::open(file->path, O_TRUNC, S_IREAD|S_IWRITE|S_IRGRP|S_IROTH);
-		::close(file->fd);
-		file->fd = -77;	// force file open by filemgr
-		// copy tmp file back (dumb, but must preserve file permissions)
-		lseek(fd, 0, SEEK_SET);
-		do {
-			bytes = read(fd, nibble, 32767);
-			file->write(nibble, bytes);
-		} while (bytes == 32767);
+		if (size < 1) {
+			// zero out the file
+			::close(file->fd);
+			file->fd = ::open(file->path, O_TRUNC, S_IREAD|S_IWRITE|S_IRGRP|S_IROTH);
+			::close(file->fd);
+			file->fd = -77;	// force file open by filemgr
+			// copy tmp file back (dumb, but must preserve file permissions)
+			lseek(fd, 0, SEEK_SET);
+			do {
+				bytes = read(fd, nibble, 32767);
+				file->write(nibble, bytes);
+			} while (bytes == 32767);
+		}
 		
 		::close(fd);
 		::close(file->fd);
@@ -406,7 +418,7 @@ int FileMgr::copyFile(const char *sourceFile, const char *targetFile) {
 
 	do {
 		len = read(sfd, buf, 4096);
-		write(dfd, buf, len);
+		if (write(dfd, buf, len) != len) break;
 	}
 	while(len == 4096);	
 	::close(dfd);
