@@ -2,7 +2,7 @@
  *  swmgr.cpp   - implementaion of class SWMgr used to interact with an install
  *				base of sword modules.
  *
- * $Id: swmgr.cpp 2113 2007-10-15 00:16:27Z scribe $
+ * $Id: swmgr.cpp 2374 2009-05-04 03:48:01Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -58,6 +58,7 @@
 #include <osislemma.h>
 #include <osisredletterwords.h>
 #include <osismorphsegmentation.h>
+#include <osisruby.h>
 #include <osisscripref.h>
 #include <thmlstrongs.h>
 #include <thmlfootnotes.h>
@@ -75,6 +76,7 @@
 #include <utf8greekaccents.h>
 #include <utf8cantillation.h>
 #include <utf8hebrewpoints.h>
+#include <utf8arabicpoints.h>
 #include <greeklexattribs.h>
 #include <swfiltermgr.h>
 #include <swcipher.h>
@@ -177,6 +179,10 @@ void SWMgr::init() {
 	optionFilters.insert(OptionFilterMap::value_type("OSISMorphSegmentation", tmpFilter));
 	cleanupFilters.push_back(tmpFilter);
 
+	tmpFilter = new OSISRuby();
+	optionFilters.insert(OptionFilterMap::value_type("OSISRuby", tmpFilter));
+	cleanupFilters.push_back(tmpFilter);
+
 	tmpFilter = new ThMLStrongs();
 	optionFilters.insert(OptionFilterMap::value_type("ThMLStrongs", tmpFilter));
 	cleanupFilters.push_back(tmpFilter);
@@ -209,6 +215,10 @@ void SWMgr::init() {
 	optionFilters.insert(OptionFilterMap::value_type("UTF8HebrewPoints", tmpFilter));
 	cleanupFilters.push_back(tmpFilter);
 
+	tmpFilter = new UTF8ArabicPoints();
+	optionFilters.insert(OptionFilterMap::value_type("UTF8ArabicPoints", tmpFilter));
+	cleanupFilters.push_back(tmpFilter);
+
 	tmpFilter = new UTF8Cantillation();
 	optionFilters.insert(OptionFilterMap::value_type("UTF8Cantillation", tmpFilter));
 	cleanupFilters.push_back(tmpFilter);
@@ -240,7 +250,24 @@ void SWMgr::init() {
 
 	teiplain = new TEIPlain();
 	cleanupFilters.push_back(teiplain);
-//#endif
+}
+
+
+SWBuf SWMgr::getHomeDir() {
+
+	// figure out 'home' directory for app data
+	SWBuf homeDir = getenv("HOME");
+	if (!homeDir.length()) {
+		// silly windows
+		homeDir = getenv("APPDATA");
+	}
+	if (homeDir.length()) {
+		if ((homeDir[homeDir.length()-1] != '\\') && (homeDir[homeDir.length()-1] != '/')) {
+			homeDir += "/";
+		}
+	}
+
+	return homeDir;
 }
 
 
@@ -259,10 +286,10 @@ void SWMgr::commonInit(SWConfig *iconfig, SWConfig *isysconfig, bool autoload, S
 	}
 	else config = 0;
 	if (isysconfig) {
-		sysconfig   = isysconfig;
+		sysConfig   = isysconfig;
 		mysysconfig = 0;
 	}
-	else sysconfig = 0;
+	else sysConfig = 0;
 
 	if (autoload)
 		Load();
@@ -294,7 +321,7 @@ SWMgr::SWMgr(const char *iConfigPath, bool autoload, SWFilterMgr *filterMgr, boo
 
 	path = iConfigPath;
 	int len = path.length();
-	if ((len < 1) || (iConfigPath[len-1] != '\\') && (iConfigPath[len-1] != '/'))
+	if ((len < 1) || ((iConfigPath[len-1] != '\\') && (iConfigPath[len-1] != '/')))
 		path += "/";
 	if (FileMgr::existsFile(path.c_str(), "mods.conf")) {
 		stdstr(&prefixPath, path.c_str());
@@ -311,7 +338,7 @@ SWMgr::SWMgr(const char *iConfigPath, bool autoload, SWFilterMgr *filterMgr, boo
 	}
 
 	config = 0;
-	sysconfig = 0;
+	sysConfig = 0;
 
 	if (autoload && configPath)
 		Load();
@@ -345,32 +372,46 @@ SWMgr::~SWMgr() {
 }
 
 
-void SWMgr::findConfig(char *configType, char **prefixPath, char **configPath, std::list<SWBuf> *augPaths, SWConfig *providedSysConf) {
+void SWMgr::findConfig(char *configType, char **prefixPath, char **configPath, std::list<SWBuf> *augPaths, SWConfig **providedSysConf) {
 	SWBuf path;
 	SWBuf sysConfPath;
 	ConfigEntMap::iterator entry;
 	ConfigEntMap::iterator lastEntry;
 
-	char *envsworddir = getenv("SWORD_PATH");
-	char *envhomedir  = getenv("HOME");
 	SWConfig *sysConf = 0;
+	SWBuf sysConfDataPath = "";
 
 	*configType = 0;
 
+	SWBuf homeDir = getHomeDir();
+
 	// check for a sysConf passed in to us
 	SWLog::getSystemLog()->logDebug("Checking for provided SWConfig(\"sword.conf\")...");
-	if (providedSysConf) {
-		sysConf = providedSysConf;
+	if (providedSysConf && *providedSysConf) {
+		sysConf = *providedSysConf;
 		SWLog::getSystemLog()->logDebug("found.");
 	}
-	else {
+
+	// if we haven't been given our datapath in a sysconf, we need to track it down
+	if (!sysConf) {
 		// check working directory
 		SWLog::getSystemLog()->logDebug("Checking working directory for sword.conf...");
 		if (FileMgr::existsFile(".", "sword.conf")) {
 			SWLog::getSystemLog()->logDebug("Overriding any systemwide or ~/.sword/ sword.conf with one found in current directory.");
 			sysConfPath = "./sword.conf";
+			sysConf = new SWConfig(sysConfPath);
+			if ((entry = sysConf->Sections["Install"].find("DataPath")) != sysConf->Sections["Install"].end()) {
+				sysConfDataPath = (*entry).second;
+			}
+			if (providedSysConf) {
+				*providedSysConf = sysConf;
+			}
+			else {
+				delete sysConf;
+				sysConf = 0;
+			}
 		}
-		else {
+		if (!sysConfDataPath.size()) {
 			SWLog::getSystemLog()->logDebug("Checking working directory for mods.conf...");
 			if (FileMgr::existsFile(".", "mods.conf")) {
 				SWLog::getSystemLog()->logDebug("found.");
@@ -388,7 +429,7 @@ void SWMgr::findConfig(char *configType, char **prefixPath, char **configPath, s
 				return;
 			}
 
-		   // check working directory ../library/
+			// check working directory ../library/
 			SWLog::getSystemLog()->logDebug("Checking working directory ../library/ for mods.d...");
 			if (FileMgr::existsDir("../library", "mods.d")) {
 				SWLog::getSystemLog()->logDebug("found.");
@@ -399,13 +440,14 @@ void SWMgr::findConfig(char *configType, char **prefixPath, char **configPath, s
 			}
 
 			// check environment variable SWORD_PATH
-			SWLog::getSystemLog()->logDebug("Checking SWORD_PATH...");
+			SWLog::getSystemLog()->logDebug("Checking $SWORD_PATH...");
 
-			if (envsworddir != NULL) {
+			SWBuf envsworddir = getenv("SWORD_PATH");
+			if (envsworddir.length()) {
 				
-				SWLog::getSystemLog()->logDebug("found (%s).", envsworddir);
+				SWLog::getSystemLog()->logDebug("found (%s).", envsworddir.c_str());
 				path = envsworddir;
-				if ((envsworddir[strlen(envsworddir)-1] != '\\') && (envsworddir[strlen(envsworddir)-1] != '/'))
+				if ((envsworddir[envsworddir.length()-1] != '\\') && (envsworddir[envsworddir.length()-1] != '/'))
 					path += "/";
 
 				SWLog::getSystemLog()->logDebug("Checking $SWORD_PATH for mods.conf...");
@@ -446,29 +488,38 @@ void SWMgr::findConfig(char *configType, char **prefixPath, char **configPath, s
 				sysConfPath = gfp;
 			delete [] globPaths;
 
-			SWBuf homeDir = envhomedir;
-			if (homeDir.size() > 0) {
-				if ((homeDir[homeDir.size()-1] != '\\') && (homeDir[homeDir.size()-1] != '/'))
-					homeDir += "/";
-				homeDir += ".sword/sword.conf";
-				if (FileMgr::existsFile(homeDir)) {
-					SWLog::getSystemLog()->logDebug("Overriding any systemwide sword.conf with one found in users home directory.");
-					sysConfPath = homeDir;
+			if (homeDir.length()) {
+				SWBuf tryPath = homeDir;
+				tryPath += ".sword/sword.conf";
+				if (FileMgr::existsFile(tryPath)) {
+					SWLog::getSystemLog()->logDebug("Overriding any systemwide sword.conf with one found in users home directory (%s)", tryPath.c_str());
+					sysConfPath = tryPath;
+				}
+				else {
+					SWBuf tryPath = homeDir;
+					tryPath += "sword/sword.conf";
+					if (FileMgr::existsFile(tryPath)) {
+						SWLog::getSystemLog()->logDebug("Overriding any systemwide sword.conf with one found in users home directory (%s)", tryPath.c_str());
+						sysConfPath = tryPath;
+					}
 				}
 			}
 		}
 	}
 
-	if (sysConfPath.size()) {
+	if (!sysConf && sysConfPath.size()) {
 		sysConf = new SWConfig(sysConfPath);
 	}
 
 	if (sysConf) {
 		if ((entry = sysConf->Sections["Install"].find("DataPath")) != sysConf->Sections["Install"].end()) {
-			path = (*entry).second;
-			if (((*entry).second.c_str()[strlen((*entry).second.c_str())-1] != '\\') && ((*entry).second.c_str()[strlen((*entry).second.c_str())-1] != '/'))
-				path += "/";
+			sysConfDataPath = (*entry).second;
+		}
+		if (sysConfDataPath.size()) {
+			if ((!sysConfDataPath.endsWith("\\")) && (!sysConfDataPath.endsWith("/")))
+				sysConfDataPath += "/";
 
+			path = sysConfDataPath;
 			SWLog::getSystemLog()->logDebug("DataPath in %s is set to %s.", sysConfPath.c_str(), path.c_str());
 			SWLog::getSystemLog()->logDebug("Checking for mods.conf in DataPath...");
 			
@@ -490,6 +541,10 @@ void SWMgr::findConfig(char *configType, char **prefixPath, char **configPath, s
 				*configType = 1;
 			}
 		}
+	}
+
+	// do some extra processing of sysConf if we have one
+	if (sysConf) {
 		if (augPaths) {
 			augPaths->clear();
 			entry     = sysConf->Sections["Install"].lower_bound("AugmentPath");
@@ -501,23 +556,72 @@ void SWMgr::findConfig(char *configType, char **prefixPath, char **configPath, s
 				augPaths->push_back(path);
 			}
 		}
-	}
-
-	if ((sysConf) && (!providedSysConf)) {
-		delete sysConf;
+		if (providedSysConf) {
+			*providedSysConf = sysConf;
+		}
+		else delete sysConf;
 	}
 
 	if (*configType)
 		return;
 
+	// WE STILL HAVEN'T FOUND A CONFIGURATION.  LET'S LOOK IN SOME OS SPECIFIC
+	// LOCATIONS
+	//
+	// for various flavors of windoze...
+	// check %ALLUSERSPROFILE%/Application Data/sword/
+
+	SWLog::getSystemLog()->logDebug("Checking $ALLUSERSPROFILE/Application Data/sword/...");
+
+	SWBuf envallusersdir  = getenv("ALLUSERSPROFILE");
+	if (envallusersdir.length()) {
+		SWLog::getSystemLog()->logDebug("found (%s).", envallusersdir.c_str());
+		path = envallusersdir;
+		if ((!path.endsWith("\\")) && (!path.endsWith("/")))
+			path += "/";
+
+		path += "Application Data/sword/";
+		SWLog::getSystemLog()->logDebug("Checking %s for mods.d...", path.c_str());
+		if (FileMgr::existsDir(path.c_str(), "mods.d")) {
+			SWLog::getSystemLog()->logDebug("found.");
+			stdstr(prefixPath, path.c_str());
+			path += "mods.d";
+			stdstr(configPath, path.c_str());
+			*configType = 1;
+			return;
+		}
+	}
+
+	// for Mac OSX...
+	// check $HOME/Library/Application Support/Sword/
+
+	SWLog::getSystemLog()->logDebug("Checking $HOME/Library/Application Support/Sword/...");
+
+	SWBuf pathCheck = getHomeDir();
+	if (pathCheck.length()) {
+		SWLog::getSystemLog()->logDebug("found (%s).", pathCheck.c_str());
+		path = pathCheck;
+		if ((!path.endsWith("\\")) && (!path.endsWith("/")))
+			path += "/";
+
+		SWLog::getSystemLog()->logDebug("Checking %s for mods.d...", path.c_str());
+		if (FileMgr::existsDir(path.c_str(), "mods.d")) {
+			SWLog::getSystemLog()->logDebug("found.");
+			stdstr(prefixPath, path.c_str());
+			path += "mods.d";
+			stdstr(configPath, path.c_str());
+			*configType = 1;
+			return;
+		}
+	}
+
+	// FINALLY CHECK PERSONAL HOME DIRECTORY LOCATIONS
 	// check ~/.sword/
 
 	SWLog::getSystemLog()->logDebug("Checking home directory for ~/.sword...");
 
-	if (envhomedir != NULL) {
-		path = envhomedir;
-		if ((envhomedir[strlen(envhomedir)-1] != '\\') && (envhomedir[strlen(envhomedir)-1] != '/'))
-			path += "/";
+	if (homeDir.length()) {
+		path = homeDir;
 		path += ".sword/";
 		SWLog::getSystemLog()->logDebug("  Checking for %smods.conf...", path.c_str());
 		if (FileMgr::existsFile(path.c_str(), "mods.conf")) {
@@ -537,6 +641,18 @@ void SWMgr::findConfig(char *configType, char **prefixPath, char **configPath, s
 			*configType = 2;
 			return;
 		}
+
+		path = homeDir;
+		path += "sword/";
+		SWLog::getSystemLog()->logDebug("  Checking for %smods.d...", path.c_str());
+		if (FileMgr::existsDir(path.c_str(), "mods.d")) {
+			SWLog::getSystemLog()->logDebug("found.");
+			stdstr(prefixPath, path.c_str());
+			path += "mods.d";
+			stdstr(configPath, path.c_str());
+			*configType = 2;
+			return;
+		}
 	}
 }
 
@@ -551,21 +667,19 @@ void SWMgr::loadConfigDir(const char *ipath)
 		rewinddir(dir);
 		while ((ent = readdir(dir))) {
 			//check whether it ends with .conf, if it doesn't skip it!
-			if (ent->d_name && (strlen(ent->d_name) > 5) && strncmp(".conf", (ent->d_name + strlen(ent->d_name) - 5), 5 )) {
+			if (!ent->d_name || (strlen(ent->d_name) <= 5) || strncmp(".conf", (ent->d_name + strlen(ent->d_name) - 5), 5 )) {
 				continue;
 			}
 			
-			if ((strcmp(ent->d_name, ".")) && (strcmp(ent->d_name, ".."))) {
-				newmodfile = ipath;
-				if ((ipath[strlen(ipath)-1] != '\\') && (ipath[strlen(ipath)-1] != '/'))
-					newmodfile += "/";
-				newmodfile += ent->d_name;
-				if (config) {
-					SWConfig tmpConfig(newmodfile.c_str());
-					*config += tmpConfig;
-				}
-				else	config = myconfig = new SWConfig(newmodfile.c_str());
+			newmodfile = ipath;
+			if ((ipath[strlen(ipath)-1] != '\\') && (ipath[strlen(ipath)-1] != '/'))
+				newmodfile += "/";
+			newmodfile += ent->d_name;
+			if (config) {
+				SWConfig tmpConfig(newmodfile.c_str());
+				*config += tmpConfig;
 			}
+			else	config = myconfig = new SWConfig(newmodfile.c_str());
 		}
 		closedir(dir);
 		
@@ -646,7 +760,9 @@ signed char SWMgr::Load() {
 	if (!config) {	// If we weren't passed a config object at construction, find a config file
 		if (!configPath) {	// If we weren't passed a config path at construction...
 			SWLog::getSystemLog()->logDebug("LOOKING UP MODULE CONFIGURATION...");
-			findConfig(&configType, &prefixPath, &configPath, &augPaths, sysconfig);
+			SWConfig *externalSysConf = sysConfig;	// if we have a sysConf before findConfig, then we were provided one from an external source.
+			findConfig(&configType, &prefixPath, &configPath, &augPaths, &sysConfig);
+			if (!externalSysConf) mysysconfig = sysConfig;	// remind us to delete our own sysConfig in d-tor
 			SWLog::getSystemLog()->logDebug("LOOKING UP MODULE CONFIGURATION COMPLETE.");
 		}
 		if (configPath) {
@@ -680,17 +796,18 @@ signed char SWMgr::Load() {
 		}
 		if (augmentHome) {
 			// augment config with ~/.sword/mods.d if it exists ---------------------
-			char *envhomedir = getenv("HOME");
-			if (envhomedir != NULL && configType != 2) { // 2 = user only
-				SWBuf path = envhomedir;
-				if ((envhomedir[strlen(envhomedir)-1] != '\\') && (envhomedir[strlen(envhomedir)-1] != '/'))
-					path += "/";
+			SWBuf homeDir = getHomeDir();
+			if (homeDir.length() && configType != 2) { // 2 = user only
+				SWBuf path = homeDir;
 				path += ".sword/";
 				augmentModules(path.c_str(), mgrModeMultiMod);
+				path = homeDir;
+				path += "sword/";
+				augmentModules(path.c_str(), mgrModeMultiMod);
 			}
 		}
 // -------------------------------------------------------------------------
-		if ( !Modules.size() ) // config exists, but no modules
+		if (!Modules.size()) // config exists, but no modules
 			ret = 1;
 
 	}
@@ -718,6 +835,8 @@ SWModule *SWMgr::CreateMod(const char *name, const char *driver, ConfigEntMap &s
 	if ((prefixPath[strlen(prefixPath)-1] != '\\') && (prefixPath[strlen(prefixPath)-1] != '/'))
 		datapath += "/";
 
+	SWBuf versification = ((entry = section.find("Versification"))  != section.end()) ? (*entry).second : (SWBuf)"KJV";
+
 	// DataPath - relative path to data used by module driver.  May be a directory, may be a File.
 	//   Typically not useful by outside world.  See AbsoluteDataPath, PrefixPath, and RelativePrefixPath
 	//   below.
@@ -749,9 +868,7 @@ SWModule *SWMgr::CreateMod(const char *name, const char *driver, ConfigEntMap &s
 	else
 		markup = FMT_GBF;
 
-	if (!stricmp(encoding.c_str(), "SCSU"))
-		enc = ENC_SCSU;
-	else if (!stricmp(encoding.c_str(), "UTF-8")) {
+	if (!stricmp(encoding.c_str(), "UTF-8")) {
 		enc = ENC_UTF8;
 	}
 	else enc = ENC_LATIN1;
@@ -795,17 +912,17 @@ SWModule *SWMgr::CreateMod(const char *name, const char *driver, ConfigEntMap &s
 
 		if (compress) {
 			if (!stricmp(driver, "zText"))
-				newmod = new zText(datapath.c_str(), name, description.c_str(), blockType, compress, 0, enc, direction, markup, lang.c_str());
-			else	newmod = new zCom(datapath.c_str(), name, description.c_str(), blockType, compress, 0, enc, direction, markup, lang.c_str());
+				newmod = new zText(datapath.c_str(), name, description.c_str(), blockType, compress, 0, enc, direction, markup, lang.c_str(), versification);
+			else	newmod = new zCom(datapath.c_str(), name, description.c_str(), blockType, compress, 0, enc, direction, markup, lang.c_str(), versification);
 		}
 	}
 
 	if (!stricmp(driver, "RawText")) {
-		newmod = new RawText(datapath.c_str(), name, description.c_str(), 0, enc, direction, markup, lang.c_str());
+		newmod = new RawText(datapath.c_str(), name, description.c_str(), 0, enc, direction, markup, lang.c_str(), versification);
 	}
 
 	if (!stricmp(driver, "RawText4")) {
-		newmod = new RawText4(datapath.c_str(), name, description.c_str(), 0, enc, direction, markup, lang.c_str());
+		newmod = new RawText4(datapath.c_str(), name, description.c_str(), 0, enc, direction, markup, lang.c_str(), versification);
 	}
 
 	// backward support old drivers
@@ -814,11 +931,11 @@ SWModule *SWMgr::CreateMod(const char *name, const char *driver, ConfigEntMap &s
 	}
 
 	if (!stricmp(driver, "RawCom")) {
-		newmod = new RawCom(datapath.c_str(), name, description.c_str(), 0, enc, direction, markup, lang.c_str());
+		newmod = new RawCom(datapath.c_str(), name, description.c_str(), 0, enc, direction, markup, lang.c_str(), versification);
 	}
 
 	if (!stricmp(driver, "RawCom4")) {
-		newmod = new RawCom4(datapath.c_str(), name, description.c_str(), 0, enc, direction, markup, lang.c_str());
+		newmod = new RawCom4(datapath.c_str(), name, description.c_str(), 0, enc, direction, markup, lang.c_str(), versification);
 	}
 
 	if (!stricmp(driver, "RawFiles")) {
@@ -888,11 +1005,11 @@ SWModule *SWMgr::CreateMod(const char *name, const char *driver, ConfigEntMap &s
 */
 	}
 
-	// if a specific module type is set in the config, use this
-	if ((entry = section.find("Type")) != section.end())
-		newmod->Type(entry->second.c_str());
+	if (newmod) {
+		// if a specific module type is set in the config, use this
+		if ((entry = section.find("Type")) != section.end())
+			newmod->Type(entry->second.c_str());
 
-	if (newmod){
 		newmod->setConfig(&section);
 	}
 	
