@@ -2,7 +2,7 @@
  *  swsearchable.h	- definition of class SWSearchable used to provide an
  *	interface for objects that be searched.
  *
- * $Id: swsearchable.cpp 1715 2005-02-08 10:06:35Z scribe $
+ * $Id: swsearchable.cpp 1959 2006-08-28 00:39:56Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -21,6 +21,7 @@
  */
 
 #include <swsearchable.h>
+#include <listkey.h>
 
 SWORD_NAMESPACE_START
 
@@ -38,7 +39,15 @@ signed char SWSearchable::createSearchFramework(void (*percent)(char, void *), v
 	return 0;
 }
 
+
 void SWSearchable::deleteSearchFramework() {
 }
 
+
+bool SWSearchable::isSearchOptimallySupported(const char *istr, int searchType, int flags, SWKey *scope) {
+	bool retVal = false;
+	search(istr, searchType, flags, scope, &retVal);
+	return retVal;
+}
+
 SWORD_NAMESPACE_END
