@@ -2,9 +2,24 @@
  *  rawfiles.cpp - code for class 'RawFiles'- a module that produces HTML HREFs
  *			pointing to actual text desired.  Uses standard
  *			files:	ot and nt using indexs ??.bks ??.cps ??.vss
+ *
+ *
+ * Copyright 2009 CrossWire Bible Society (http://www.crosswire.org)
+ *	CrossWire Bible Society
+ *	P. O. Box 2528
+ *	Tempe, AZ  85280-2528
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the
+ * Free Software Foundation version 2.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
  */
 
-
 #include <ctype.h>
 #include <stdio.h>
 #include <fcntl.h>
@@ -13,6 +28,7 @@
 #include <rawfiles.h>
 #include <filemgr.h>
 #include <versekey.h>
+#include <sysdata.h>
 
 SWORD_NAMESPACE_START
 
@@ -57,16 +73,9 @@ SWBuf &RawFiles::getRawEntryBuf() {
 	FileDesc *datafile;
 	long  start = 0;
 	unsigned short size = 0;
-	VerseKey *key = 0;
+	VerseKey *key = &getVerseKey();
 
-	SWTRY {
-		key = SWDYNAMIC_CAST(VerseKey, this->key);
-	}
-	SWCATCH ( ... ) {}
-	if (!key)
-		key = new VerseKey(this->key);
-
-	findOffset(key->Testament(), key->Index(), &start, &size);
+	findOffset(key->Testament(), key->TestamentIndex(), &start, &size);
 
 	entryBuf = "";
 	if (size) {
@@ -88,10 +97,6 @@ SWBuf &RawFiles::getRawEntryBuf() {
 		}
 		FileMgr::getSystemFileMgr()->close(datafile);
 	}
-
-	if (key != this->key)
-		delete key;
-
 	return entryBuf;
 }
 
@@ -105,17 +110,11 @@ void RawFiles::setEntry(const char *inbuf, long len) {
 	FileDesc *datafile;
 	long  start;
 	unsigned short size;
-	VerseKey *key = 0;
+	VerseKey *key = &getVerseKey();
 
 	len = (len<0)?strlen(inbuf):len;
-	SWTRY {
-		key = SWDYNAMIC_CAST(VerseKey, this->key);
-	}
-	SWCATCH ( ... ) {}
-	if (!key)
-		key = new VerseKey(this->key);
 
-	findOffset(key->Testament(), key->Index(), &start, &size);
+	findOffset(key->Testament(), key->TestamentIndex(), &start, &size);
 
 	if (size) {
 		SWBuf tmpbuf;
@@ -129,7 +128,7 @@ void RawFiles::setEntry(const char *inbuf, long len) {
 		entryBuf = path;
 		entryBuf += '/';
 		tmpbuf = getNextFilename();
-		doSetText(key->Testament(), key->Index(), tmpbuf);
+		doSetText(key->Testament(), key->TestamentIndex(), tmpbuf);
 		entryBuf += tmpbuf;
 	}
 	datafile = FileMgr::getSystemFileMgr()->open(entryBuf, FileMgr::CREAT|FileMgr::WRONLY|FileMgr::TRUNC);
@@ -137,9 +136,6 @@ void RawFiles::setEntry(const char *inbuf, long len) {
 		datafile->write(inbuf, len);
 	}
 	FileMgr::getSystemFileMgr()->close(datafile);
-	
-	if (key != this->key)
-		delete key;
 }
 
 
@@ -154,36 +150,17 @@ void RawFiles::linkEntry(const SWKey *inkey) {
 
 	long  start;
 	unsigned short size;
-	const VerseKey *key = 0;
+	const VerseKey *key = &getVerseKey();
 
-	SWTRY {
-		key = SWDYNAMIC_CAST(VerseKey, inkey);
-	}
-	SWCATCH ( ... ) {}
-	if (!key)
-		key = new VerseKey(this->key);
-
-	findOffset(key->Testament(), key->Index(), &start, &size);
+	findOffset(key->Testament(), key->TestamentIndex(), &start, &size);
 
 	if (size) {
 		SWBuf tmpbuf;
 		readText(key->Testament(), start, size + 2, tmpbuf);
 
-		if (key != inkey)
-			delete key;
-		key = 0;
-
-		SWTRY {
-			key = SWDYNAMIC_CAST(VerseKey, inkey);
-		}
-		SWCATCH ( ... ) {}
-		if (!key)
-			key = new VerseKey(this->key);
-		doSetText(key->Testament(), key->Index(), tmpbuf.c_str());
+		key = &getVerseKey(inkey);
+		doSetText(key->Testament(), key->TestamentIndex(), tmpbuf.c_str());
 	}
-	
-	if (key != inkey)
-		delete key;
 }
 
 
@@ -194,20 +171,8 @@ void RawFiles::linkEntry(const SWKey *inkey) {
  */
 
 void RawFiles::deleteEntry() {
-
-	VerseKey *key = 0;
-
-	SWTRY {
-		key = SWDYNAMIC_CAST(VerseKey, this->key);
-	}
-	SWCATCH ( ... ) {}
-	if (!key)
-		key = new VerseKey(this->key);
-
-	doSetText(key->Testament(), key->Index(), "");
-
-	if (key != this->key)
-		delete key;
+	VerseKey *key = &getVerseKey();
+	doSetText(key->Testament(), key->TestamentIndex(), "");
 }
 
 
@@ -220,32 +185,40 @@ void RawFiles::deleteEntry() {
 
 char *RawFiles::getNextFilename() {
 	static char incfile[255];
-	long number;
+	__u32 number;
 	FileDesc *datafile;
 
 	sprintf(incfile, "%s/incfile", path);
 	datafile = FileMgr::getSystemFileMgr()->open(incfile, FileMgr::RDONLY);
-	if (datafile->read(&number, 4) != 4)
-		number = 0;
+
+	if (datafile->read(&number, 4) != 4) number = 0;
+	number = swordtoarch32(number);
+
 	number++;
 	FileMgr::getSystemFileMgr()->close(datafile);
 	
 	datafile = FileMgr::getSystemFileMgr()->open(incfile, FileMgr::CREAT|FileMgr::WRONLY|FileMgr::TRUNC);
+	sprintf(incfile, "%.7d", number-1);
+
+	number = archtosword32(number);
 	datafile->write(&number, 4);
+
 	FileMgr::getSystemFileMgr()->close(datafile);
-	sprintf(incfile, "%.7ld", number-1);
 	return incfile;
 }
 
 
 char RawFiles::createModule (const char *path) {
 	char *incfile = new char [ strlen (path) + 16 ];
-    static long zero = 0;
+
+	__u32 zero = 0;
+	zero = archtosword32(zero);
+
 	FileDesc *datafile;
 
 	sprintf(incfile, "%s/incfile", path);
 	datafile = FileMgr::getSystemFileMgr()->open(incfile, FileMgr::CREAT|FileMgr::WRONLY|FileMgr::TRUNC);
-    delete [] incfile;
+	delete [] incfile;
 	datafile->write(&zero, 4);
 	FileMgr::getSystemFileMgr()->close(datafile);
 
