@@ -1,3 +1,20 @@
+/*
+ * Copyright 2009 CrossWire Bible Society (http://www.crosswire.org)
+ *	CrossWire Bible Society
+ *	P. O. Box 2528
+ *	Tempe, AZ  85280-2528
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the
+ * Free Software Foundation version 2.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
+ */
+
 #include <entriesblk.h>
 #include <stdlib.h>
 #include <string.h>
@@ -125,7 +142,7 @@ int EntriesBlock::addEntry(const char *entry) {
 const char *EntriesBlock::getEntry(int entryIndex) {
 	unsigned long offset;
 	unsigned long size;
-	static char *empty = "";
+	static const char *empty = "";
 
 	getMetaEntry(entryIndex, &offset, &size);
 	return (offset) ? block+offset : empty;
