@@ -1,6 +1,22 @@
 /******************************************************************************
  *  lzsscomprs.cpp   - code for class 'LZSSCompress'- a driver class that
  *			provides LZSS compression
+ *
+ *
+ * Copyright 2009 CrossWire Bible Society (http://www.crosswire.org)
+ *	CrossWire Bible Society
+ *	P. O. Box 2528
+ *	Tempe, AZ  85280-2528
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the
+ * Free Software Foundation version 2.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
  */
 
 #include <stdlib.h>
@@ -602,9 +618,9 @@ void LZSSCompress::Decode(void)
 				break;
 
 			if (SendChars((char *) c, 1) != 1) {
-				totalLen++;
 				break;
 			}
+			totalLen++;
 
 			// Add to buffer, and increment to next spot. Wrap at end.
 
@@ -657,9 +673,9 @@ void LZSSCompress::Decode(void)
 			// Add the "len" :characters to the output stream.
 
 			if (SendChars((char *) c, len) != (unsigned int)len) {
-				totalLen += len;
 				break;
 			}
+			totalLen += len;
 		}
 	}
 	slen = totalLen;
