@@ -1,8 +1,24 @@
 /******************************************************************************
  *  rawstr.cpp   - code for class 'RawStr'- a module that reads raw text
- *				files:  ot and nt using indexs ??.bks ??.cps ??.vss
- *				and provides lookup and parsing functions based on
- *				class StrKey
+ *		   files:  ot and nt using indexs ??.bks ??.cps ??.vss
+ *		   and provides lookup and parsing functions based on
+ *		   class StrKey
+ *
+ *
+ * Copyright 2009 CrossWire Bible Society (http://www.crosswire.org)
+ *	CrossWire Bible Society
+ *	P. O. Box 2528
+ *	Tempe, AZ  85280-2528
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the
+ * Free Software Foundation version 2.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
  */
 
 #include <stdio.h>
@@ -26,6 +42,7 @@ SWORD_NAMESPACE_START
  */
 
 int RawStr4::instance = 0;
+const int RawStr4::IDXENTRYSIZE = 8;
 
 
 /******************************************************************************
@@ -88,7 +105,8 @@ RawStr4::~RawStr4()
  *		buf		- address of pointer to allocate for storage of string
  */
 
-void RawStr4::getIDXBufDat(long ioffset, char **buf) {
+void RawStr4::getIDXBufDat(long ioffset, char **buf) const
+{
 	int size;
 	char ch;
 	if (datfd > 0) {
@@ -121,14 +139,14 @@ void RawStr4::getIDXBufDat(long ioffset, char **buf) {
  *		buf		- address of pointer to allocate for storage of string
  */
 
-void RawStr4::getIDXBuf(long ioffset, char **buf)
+void RawStr4::getIDXBuf(long ioffset, char **buf) const
 {
-	long offset;
+	__u32 offset;
 	
 	if (idxfd > 0) {
 		idxfd->seek(ioffset, SEEK_SET);
-		idxfd->read(&offset, 4);
 
+		idxfd->read(&offset, 4);
 		offset = swordtoarch32(offset);
 
 		getIDXBufDat(offset, buf);
@@ -157,67 +175,88 @@ void RawStr4::getIDXBuf(long ioffset, char **buf)
  * RET: error status -1 general error; -2 new file
  */
 
-signed char RawStr4::findOffset(const char *ikey, long *start, unsigned long *size, long away, long *idxoff)
+signed char RawStr4::findOffset(const char *ikey, __u32 *start, __u32 *size, long away, __u32 *idxoff) const
 {
-	char *trybuf, *key = 0, quitflag = 0;
+	char *trybuf, *maxbuf, *key = 0, quitflag = 0;
 	signed char retval = -1;
 	long headoff, tailoff, tryoff = 0, maxoff = 0;
+	int diff = 0;
+	bool awayFromSubstrCheck = false;
 
 	if (idxfd->getFd() >=0) {
 		tailoff = maxoff = idxfd->seek(0, SEEK_END) - 8;
+
 		retval = (tailoff >= 0) ? 0 : -2;	// if NOT new file
-		if (*ikey) {
+		if (*ikey && retval != -2) {
 			headoff = 0;
 
 			stdstr(&key, ikey, 3);
 			toupperstr_utf8(key, strlen(key)*3);
 
-			trybuf = 0;
+			int keylen = strlen(key);
+			bool substr = false;
+
+			trybuf = maxbuf = 0;
+			getIDXBuf(maxoff, &maxbuf);
 
 			while (headoff < tailoff) {
-				tryoff = (lastoff == -1) ? headoff + ((((tailoff / 8) - (headoff / 8))) / 2) * 8 : lastoff; 
+				tryoff = (lastoff == -1) ? headoff + ((((tailoff / 8) - (headoff / 8))) / 2) * 8 : lastoff;
 				lastoff = -1;
 				getIDXBuf(tryoff, &trybuf);
 
-				if (!*trybuf) {		// In case of extra entry at end of idx
+				if (!*trybuf && tryoff) {		// In case of extra entry at end of idx (not first entry)
 					tryoff += (tryoff > (maxoff / 2))?-8:8;
 					retval = -1;
 					break;
 				}
-					
-				if (!strcmp(key, trybuf))
+
+				diff = strcmp(key, trybuf);
+
+				if (!diff)
 					break;
 
-				int diff = strcmp(key, trybuf);
+				if (!strncmp(trybuf, key, keylen)) substr = true;
+
 				if (diff < 0)
 					tailoff = (tryoff == headoff) ? headoff : tryoff;
 				else headoff = tryoff;
+
 				if (tailoff == headoff + 8) {
 					if (quitflag++)
 						headoff = tailoff;
 				}
 			}
-			if (headoff >= tailoff)
+
+			// didn't find exact match
+			if (headoff >= tailoff) {
 				tryoff = headoff;
+				if (!substr && ((tryoff != maxoff)||(strncmp(key, maxbuf, keylen)<0))) {
+					awayFromSubstrCheck = true;
+					away--;	// if our entry doesn't startwith our key, prefer the previous entry over the next
+				}
+			}
 			if (trybuf)
 				free(trybuf);
 			delete [] key;
+                        if (maxbuf)
+                        	free(maxbuf);
 		}
 		else	tryoff = 0;
 
 		idxfd->seek(tryoff, SEEK_SET);
 
-		*start = *size = 0;
-		idxfd->read(start, 4);
-		idxfd->read(size, 4);
+		__u32 tmpStart, tmpSize;
+		*start = *size = tmpStart = tmpSize = 0;
+		idxfd->read(&tmpStart, 4);
+		idxfd->read(&tmpSize, 4);
 		if (idxoff)
 			*idxoff = tryoff;
 
-		*start = swordtoarch32(*start);
-		*size  = swordtoarch32(*size);
+		*start = swordtoarch32(tmpStart);
+		*size  = swordtoarch32(tmpSize);
 
 		while (away) {
-			long laststart = *start;
+			unsigned long laststart = *start;
 			unsigned long lastsize = *size;
 			long lasttry = tryoff;
 			tryoff += (away > 0) ? 8 : -8;
@@ -228,7 +267,8 @@ signed char RawStr4::findOffset(const char *ikey, long *start, unsigned long *si
 			else if (idxfd->seek(tryoff, SEEK_SET) < 0)
 				bad = true;
 			if (bad) {
-				retval = -1;
+				if(!awayFromSubstrCheck)
+					retval = -1;
 				*start = laststart;
 				*size = lastsize;
 				tryoff = lasttry;
@@ -236,15 +276,15 @@ signed char RawStr4::findOffset(const char *ikey, long *start, unsigned long *si
 					*idxoff = tryoff;
 				break;
 			}
-			idxfd->read(start, 4);
-			idxfd->read(size, 4);
+			idxfd->read(&tmpStart, 4);
+			idxfd->read(&tmpSize, 4);
 			if (idxoff)
 				*idxoff = tryoff;
 
-			*start = swordtoarch32(*start);
-			*size  = swordtoarch32(*size);
+			*start = swordtoarch32(tmpStart);
+			*size  = swordtoarch32(tmpSize);
 
-			if (((laststart != *start) || (lastsize != *size)) && (*start >= 0) && (*size)) 
+			if (((laststart != *start) || (lastsize != *size)) && (*size)) 
 				away += (away < 0) ? 1 : -1;
 		}
 	
@@ -261,65 +301,6 @@ signed char RawStr4::findOffset(const char *ikey, long *start, unsigned long *si
 }
 
 
-/******************************************************************************
- * RawStr4::preptext	- Prepares the text before returning it to external
- *					objects
- *
- * ENT:	buf	- buffer where text is stored and where to store the prep'd
- *				text.
- */
-
-void RawStr4::prepText(SWBuf &buf) {
-	unsigned int to, from; 
-	char space = 0, cr = 0, realdata = 0, nlcnt = 0;
-	char *rawBuf = buf.getRawData();
-	for (to = from = 0; rawBuf[from]; from++) {
-		switch (rawBuf[from]) {
-		case 10:
-			if (!realdata)
-				continue;
-			space = (cr) ? 0 : 1;
-			cr = 0;
-			nlcnt++;
-			if (nlcnt > 1) {
-//				*to++ = nl;
-				rawBuf[to++] = 10;
-//				*to++ = nl[1];
-//				nlcnt = 0;
-			}
-			continue;
-		case 13:
-			if (!realdata)
-				continue;
-//			*to++ = nl[0];
-			rawBuf[to++] = 10;
-			space = 0;
-			cr = 1;
-			continue;
-		}
-		realdata = 1;
-		nlcnt = 0;
-		if (space) {
-			space = 0;
-			if (rawBuf[from] != ' ') {
-				rawBuf[to++] = ' ';
-				from--;
-				continue;
-			}
-		}
-		rawBuf[to++] = rawBuf[from];
-	}
-	buf.setSize(to);
-
-	while (to > 1) {			// remove trailing excess
-		to--;
-		if ((rawBuf[to] == 10) || (rawBuf[to] == ' '))
-			buf.setSize(to);
-		else break;
-	}
-}
-
-
 /******************************************************************************
  * RawStr4::readtext	- gets text at a given offset
  *
@@ -330,21 +311,23 @@ void RawStr4::prepText(SWBuf &buf) {
  *
  */
 
-void RawStr4::readText(long istart, unsigned long *isize, char **idxbuf, SWBuf &buf)
+void RawStr4::readText(__u32 istart, __u32 *isize, char **idxbuf, SWBuf &buf)
 {
 	unsigned int ch;
 	char *idxbuflocal = 0;
 	getIDXBufDat(istart, &idxbuflocal);
-	long start = istart;
+	__u32 start = istart;
 
 	do {
 		if (*idxbuf)
 			delete [] *idxbuf;
-		*idxbuf = new char [ (*isize) ];
 
 		buf = "";
 		buf.setFillByte(0);
-		buf.setSize(*isize);
+		buf.setSize(++(*isize));
+
+		*idxbuf = new char [ (*isize) ];
+
 		datfd->seek(start, SEEK_SET);
 		datfd->read(buf.getRawData(), (int)((*isize) - 1));
 
@@ -364,7 +347,6 @@ void RawStr4::readText(long istart, unsigned long *isize, char **idxbuf, SWBuf &
 				}
 			}
 			findOffset(buf.c_str() + 6, &start, isize);
-
 		}
 		else break;
 	}
@@ -390,12 +372,12 @@ void RawStr4::readText(long istart, unsigned long *isize, char **idxbuf, SWBuf &
 
 void RawStr4::doSetText(const char *ikey, const char *buf, long len) {
 
-	long start, outstart;
-	long idxoff;
-	long endoff;
-	long shiftSize;
-	unsigned long size;
-	unsigned long outsize;
+	__u32 start, outstart;
+	__u32 idxoff;
+	__u32 endoff;
+	__s32 shiftSize;
+	__u32 size;
+	__u32 outsize;
 	static const char nl[] = {13, 10};
 	char *tmpbuf = 0;
 	char *key = 0;
