@@ -1,18 +1,24 @@
 /***************************************************************************
-                     gbfthml.cpp  -  GBF to ThML filter
-                             -------------------
-    begin                : 1999-10-27
-    copyright            : 2001 by CrossWire Bible Society
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+ *                    gbfthml.cpp  -  GBF to ThML filter
+ *                            -------------------
+ *   begin                : 1999-10-27
+ *   copyright            : 2001 by CrossWire Bible Society
+ *
+ * Copyright 2009 CrossWire Bible Society (http://www.crosswire.org)
+ *	CrossWire Bible Society
+ *	P. O. Box 2528
+ *	Tempe, AZ  85280-2528
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the
+ * Free Software Foundation version 2.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
+ */
 
 #include <stdlib.h>
 #include <gbfthml.h>
@@ -30,7 +36,6 @@ char GBFThML::processText(SWBuf &text, const SWKey *key, const SWModule *module)
 	char token[2048];
 	int tokpos = 0;
 	bool intoken 	= false;
-	int len;
 	const char *tok;
 
 	SWBuf orig = text;
