@@ -1,19 +1,25 @@
 /***************************************************************************
-                          OSISWEBIF.cpp  -   OSIS to HTML filter with hrefs 
-			        for strongs and morph tags
-                             -------------------
-    begin                    : 2003-10-23
-    copyright            : 2003 by CrossWire Bible Society
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+ *                         OSISWEBIF.cpp  -   OSIS to HTML filter with hrefs 
+ *			        for strongs and morph tags
+ *                            -------------------
+ *   begin                    : 2003-10-23
+ *   copyright            : 2003 by CrossWire Bible Society
+ *
+ * Copyright 2009 CrossWire Bible Society (http://www.crosswire.org)
+ *	CrossWire Bible Society
+ *	P. O. Box 2528
+ *	Tempe, AZ  85280-2528
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the
+ * Free Software Foundation version 2.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
+ */
 
 #include <stdlib.h>
 #include <osiswebif.h>
@@ -169,6 +175,14 @@ bool OSISWEBIF::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *
 			}
 		}
 
+                // Milestoned paragraphs, created by osis2mod
+                // <div type="paragraph" sID.../>
+                // <div type="paragraph" eID.../>
+                else if (tag.isEmpty() && !strcmp(tag.getName(), "div") && tag.getAttribute("type") && !strcmp(tag.getAttribute("type"), "paragraph")) {
+			// This is properly handled by base class.
+			return OSISHTMLHREF::handleToken(buf, token, userData);
+                }
+
 		// ok to leave these in
 		else if (!strcmp(tag.getName(), "div")) {
 			buf += tag;
