@@ -1,19 +1,25 @@
 /***************************************************************************
-                          plainfootnotes.cpp  -  description
-                             -------------------
-    begin                : Wed Oct 13 1999
-    copyright            : (C) 1999 by The team of BibleTime
-    email                : info@bibletime.de
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+ *                         plainfootnotes.cpp  -  description
+ *                            -------------------
+ *   begin                : Wed Oct 13 1999
+ *   copyright            : (C) 1999 by The team of BibleTime
+ *   email                : info@bibletime.de
+ *
+ * Copyright 2009 CrossWire Bible Society (http://www.crosswire.org)
+ *	CrossWire Bible Society
+ *	P. O. Box 2528
+ *	Tempe, AZ  85280-2528
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the
+ * Free Software Foundation version 2.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
+ */
 
 #include <plainfootnotes.h>
 #include <swkey.h>
