@@ -4,7 +4,7 @@
  *  				many filters will need and can use as a starting
  *  				point. 
  *
- * $Id: swbasicfilter.cpp 1984 2006-10-08 05:06:52Z scribe $
+ * $Id: swbasicfilter.cpp 2167 2008-05-16 23:23:39Z scribe $
  *
  * Copyright 2001 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -289,8 +289,8 @@ char SWBasicFilter::processText(SWBuf &text, const SWKey *key, const SWModule *m
 	int tokpos = 0;
 	bool intoken = false;
 	bool inEsc = false;
-	char escStartPos = 0, escEndPos = 0;
-	char tokenStartPos = 0, tokenEndPos = 0;
+	int escStartPos = 0, escEndPos = 0;
+	int tokenStartPos = 0, tokenEndPos = 0;
 	SWBuf lastTextNode;
 	BasicFilterUserData *userData = createUserData(module, key);
 
