@@ -1,18 +1,25 @@
 /***************************************************************************
-                     thmlrtf.cpp  -  ThML to RTF filter
-                             -------------------
-    begin                : 1999-10-27
-    copyright            : 2001 by CrossWire Bible Society
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+ *                    thmlrtf.cpp  -  ThML to RTF filter
+ *                            -------------------
+ *   begin                : 1999-10-27
+ *   copyright            : 2001 by CrossWire Bible Society
+ *
+ *
+ * Copyright 2009 CrossWire Bible Society (http://www.crosswire.org)
+ *	CrossWire Bible Society
+ *	P. O. Box 2528
+ *	Tempe, AZ  85280-2528
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the
+ * Free Software Foundation version 2.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
+ */
 
 #include <stdlib.h>
 #include <thmlrtf.h>
@@ -32,7 +39,7 @@ ThMLRTF::ThMLRTF() {
 
 	setEscapeStringCaseSensitive(true);
 
-	addEscapeStringSubstitute("nbsp", " ");
+     addEscapeStringSubstitute("nbsp", "\302\240");
 	addEscapeStringSubstitute("apos", "'");
 	addEscapeStringSubstitute("quot", "\"");
 	addEscapeStringSubstitute("amp", "&");
@@ -148,7 +155,7 @@ ThMLRTF::ThMLRTF() {
 	addTokenSubstitute("b", "{\\b1 ");
 	addTokenSubstitute("/b", "}");
 	addTokenSubstitute("p", "{\\fi200\\par}");
-	addTokenSubstitute("p /", "\\par\\pard ");
+	addTokenSubstitute("p /", "\\pard\\par\\par ");
 
 	//we need uppercase forms for the moment to support a few early ThML modules that aren't XHTML compliant
 	addTokenSubstitute("BR", "\\line ");
@@ -159,6 +166,8 @@ ThMLRTF::ThMLRTF() {
 	addTokenSubstitute("P", "\\par ");
 	addTokenSubstitute("scripture", "{\\i1 ");
 	addTokenSubstitute("/scripture", "}");
+     addTokenSubstitute("center", "\\qc ");
+     addTokenSubstitute("/center", "\\pard ");
 }
 
 
