@@ -2,9 +2,24 @@
  *
  * thmlscripref -	SWFilter descendant to hide or show scripture
  *			referebces in a ThML module.
+ *
+ *
+ * Copyright 2009 CrossWire Bible Society (http://www.crosswire.org)
+ *	CrossWire Bible Society
+ *	P. O. Box 2528
+ *	Tempe, AZ  85280-2528
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the
+ * Free Software Foundation version 2.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
  */
 
-
 #include <stdlib.h>
 #include <stdio.h>
 #include <thmlscripref.h>
@@ -38,7 +53,13 @@ char ThMLScripref::processText(SWBuf &text, const SWKey *key, const SWModule *mo
 	SWBuf refs = "";
 	int footnoteNum = 1;
 	char buf[254];
-	VerseKey parser = key->getText();
+	SWKey *p = (module) ? module->CreateKey() : (key) ? key->clone() : new VerseKey();
+        VerseKey *parser = SWDYNAMIC_CAST(VerseKey, p);
+        if (!parser) {
+        	delete p;
+                parser = new VerseKey();
+        }
+	*parser = key->getText();
 
 	SWBuf orig = text;
 	const char *from = orig.c_str();
@@ -77,8 +98,8 @@ char ThMLScripref::processText(SWBuf &text, const SWKey *key, const SWModule *mo
 						startTag.setAttribute("swordFootnote", buf);
 						SWBuf passage = startTag.getAttribute("passage");
 						if (passage.length())
-							refs = parser.ParseVerseList(passage.c_str(), parser, true).getRangeText();
-						else	refs = parser.ParseVerseList(tagText.c_str(), parser, true).getRangeText();
+							refs = parser->ParseVerseList(passage.c_str(), *parser, true).getRangeText();
+						else	refs = parser->ParseVerseList(tagText.c_str(), *parser, true).getRangeText();
 						module->getEntryAttributes()["Footnote"][buf]["refList"] = refs.c_str();
 					}
 					hide = false;
@@ -117,6 +138,7 @@ char ThMLScripref::processText(SWBuf &text, const SWKey *key, const SWModule *mo
 		}
 		else tagText += *from;
 	}
+        delete parser;
 	return 0;
 }
 
