@@ -1,7 +1,7 @@
 /******************************************************************************
 *  swbuf.cpp  - code for SWBuf used as a transport and utility for data buffers
 *
-* $Id: swbuf.cpp 2169 2008-05-18 02:50:53Z scribe $
+* $Id: swbuf.cpp 2198 2008-09-11 20:59:30Z scribe $
 *
 * Copyright 2003 CrossWire Bible Society (http://www.crosswire.org)
 *	CrossWire Bible Society
@@ -76,7 +76,7 @@ SWBuf::SWBuf(unsigned long initSize) {
 * WARNING: This function can only write at most
 * JUNKBUFSIZE to the string per call.
 */
-void SWBuf::setFormatted(const char *format, ...) {
+SWBuf &SWBuf::setFormatted(const char *format, ...) {
 	va_list argptr;
 
 	va_start(argptr, format);
@@ -90,6 +90,7 @@ void SWBuf::setFormatted(const char *format, ...) {
 	va_start(argptr, format);
 	end = vsprintf(buf, format, argptr) + buf;
 	va_end(argptr);
+	return *this;
 }
 
 /******************************************************************************
