@@ -20,6 +20,8 @@
 #include <string.h>
 
 #include <sysdata.h>
+#include <swlog.h>
+#include <swbuf.h>
 
 
 SWORD_NAMESPACE_START
@@ -222,6 +224,12 @@ __u32 getUniCharFromUTF8(const unsigned char **buf) {
 		multibuf[0] <<= 1;
 		multibuf[subsequent] = (*buf)[subsequent];
 		multibuf[subsequent] &= 63;
+		// subsequent byte did not begin with 10XXXXXX
+		// move our buffer to here and error out
+		if (((*buf)[subsequent] - multibuf[subsequent]) != 128) {
+			*buf += subsequent;
+			return 0;
+		}
 		ch <<= 6;
 		ch |= multibuf[subsequent];
 	}
@@ -235,4 +243,30 @@ __u32 getUniCharFromUTF8(const unsigned char **buf) {
 }
 
 
+
+SWBuf assureValidUTF8(const char *buf) {
+
+	SWBuf myCopy = buf;
+	const unsigned char *b = (const unsigned char *)myCopy.c_str();
+	const unsigned char *q = 0;
+	bool invalidChar = false;
+	while (*b) {
+		q = b;
+		if (!getUniCharFromUTF8(&b)) {
+			long len = b - q;
+			if (len) {
+				invalidChar = true;
+				for (long start = q - (const unsigned char *)myCopy.c_str(); len; len--) {
+					myCopy[start+len-1] = 0x1a;	// unicode replacement character
+				}
+				
+			}
+		}
+	}
+	if (invalidChar) {
+//		SWLog::getSystemLog()->logWarning("Changing invalid UTF-8 string (%s) to (%s)\n", buf, myCopy.c_str());
+	}
+	return myCopy;
+}
+
 SWORD_NAMESPACE_END
