@@ -1,7 +1,7 @@
 /******************************************************************************
  *  utilxml.cpp   - implementaion of utility classes to handle XML processing
  *
- * $Id: utilxml.cpp 1947 2006-07-16 02:01:52Z scribe $
+ * $Id: utilxml.cpp 2378 2009-05-04 23:18:51Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -121,6 +121,22 @@ XMLTag::XMLTag(const char *tagString) {
 	setText(tagString);
 }
 
+XMLTag::XMLTag(const XMLTag& t) : attributes(t.attributes)  {
+	parsed = t.parsed;
+	empty = t.empty;
+	endTag = t.endTag;
+	if (t.buf) {
+		int len = strlen(t.buf);
+		buf = new char[len + 1];
+		memcpy(buf, t.buf, len + 1);
+	}
+	if (t.name) {
+		int len = strlen(t.name);
+		name = new char[len + 1];
+		memcpy(name, t.name, len + 1);
+	}
+}
+
 void XMLTag::setText(const char *tagString) {
 	parsed = false;
 	empty  = false;
@@ -224,12 +240,39 @@ const char *XMLTag::getAttribute(const char *attribName, int partNum, char partS
 }
 
 
-const char *XMLTag::setAttribute(const char *attribName, const char *attribValue) {
+const char *XMLTag::setAttribute(const char *attribName, const char *attribValue, int partNum, char partSplit) {
 	if (!parsed)
 		parse();
+
+	SWBuf newVal = "";
+	// set part of an attribute
+	if (partNum > -1) {
+		const char *wholeAttr = getAttribute(attribName);
+		int attrCount = getAttributePartCount(attribName, partSplit);
+		for (int i = 0; i < attrCount; i++) {
+			if (i == partNum) {
+				if (attribValue) {
+					newVal += attribValue;
+					newVal += partSplit;
+				}
+				else {
+					// discard this part per null attribValue
+				}
+			}
+			else {
+				newVal += getPart(wholeAttr, i, partSplit);
+				newVal += partSplit;
+			}
+		}
+		if (newVal.length()) newVal--;	// discard the last partSplit
+		attribValue = (!attribValue && !newVal.length()) ? 0 : newVal.c_str();
+	}
+
+	// perform the actual set
 	if (attribValue)
 		attributes[attribName] = attribValue;
 	else	attributes.erase(attribName);
+
 	return attribValue;
 }
 
@@ -266,4 +309,13 @@ const char *XMLTag::toString() const {
 }
 
 
+// if an eID is provided, then we check to be sure we have an attribute <tag eID="xxx"/> value xxx equiv to what is given us
+// otherwise, we return if we're a simple XML end </tag>.
+bool XMLTag::isEndTag(const char *eID) const {
+	if (eID) {
+		return (SWBuf(eID) == getAttribute("eID"));
+	}
+	return endTag;
+}
+
 SWORD_NAMESPACE_END
