@@ -24,14 +24,15 @@ using namespace sword;
 
 int main(int argc, char **argv) {
 	if (argc != 3) {
-		fprintf(stderr, "usage: %s <locale_name> <text>\n", *argv);
+		std::cerr <<  "usage: " << *argv << " <locale_name> <text>\n";
 		exit(-1);
 	}
 
 	LocaleMgr lm;
 
-	printf("%s\n", lm.translate(argv[1], argv[2]));
+	std::cout << lm.translate(argv[2], argv[1]) << "\n";
 
+/*
 	VerseKey bla;
 	bla = "James 1:19";
 
@@ -45,6 +46,7 @@ int main(int argc, char **argv) {
 	key2.setLocale("en");
 	ListKey list = key2.ParseVerseList("Luke 3:23-28",key2, true);
 	std::cout << list << std::endl;
+*/
 
 
 }
