@@ -1,3 +1,20 @@
+/*
+ * Copyright 2009 CrossWire Bible Society (http://www.crosswire.org)
+ *	CrossWire Bible Society
+ *	P. O. Box 2528
+ *	Tempe, AZ  85280-2528
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the
+ * Free Software Foundation version 2.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
+ */
+
 #include <swmgr.h>
 #include <swlog.h>
 #include <iostream>
@@ -20,6 +37,7 @@ int main(int argc, char **argv) {
 	std::cerr << "\nconfigPath: " << mymgr.configPath << "\n\n";
 
 
+
 	ModMap::iterator it;
 
 	for (it = mymgr.Modules.begin(); it != mymgr.Modules.end(); it++) {
@@ -31,8 +49,11 @@ int main(int argc, char **argv) {
 			std::cout << (const char *) *(*it).second << "\n\n";
 		}
 	}
+
 	SWModule *mhc = mymgr.Modules["MHC"];
+
 	if (mhc) {
+		std::cout << "MHC, Lang = " << mhc->Lang() << "\n\n";
 		for (mhc->Key("Gen 1:1"); mhc->Key() < (VerseKey) "Gen 1:10"; (*mhc)++)
 			std::cout << (const char *) *mhc << "\n";
 	}
