@@ -14,6 +14,11 @@
  * General Public License for more details.
  *
  */
+
+#ifdef _MSC_VER
+	#pragma warning( disable: 4251 )
+#endif
+
 #include <ctype.h>
 #include <stdio.h>
 #include <fcntl.h>
