@@ -23,11 +23,12 @@
 #define FMT_CGI 127
 
 #include <encfiltmgr.h>
+
 #ifndef NO_SWORD_NAMESPACE
 using namespace sword;
 #endif
 
-class SWDLLEXPORT DiathekeFilterMgr : public EncodingFilterMgr {
+class DiathekeFilterMgr : public EncodingFilterMgr {
 protected:
         SWFilter* fromthml;
         SWFilter* fromgbf;
