@@ -15,6 +15,10 @@
  *
  */
 
+#ifdef _MSC_VER
+	#pragma warning( disable: 4251 )
+#endif
+
 #include <stdio.h>
 #include <iostream>
 
@@ -143,9 +147,11 @@ int main(int argc, char **argv) {
 				exit(-1);
 			}
 		}
-		if (!fourByteSize)
-			RawText::createModule(outPath, v11n);
-		else	RawText4::createModule(outPath, v11n);
+		else {
+			if (!fourByteSize)
+				RawText::createModule(outPath, v11n);
+			else	RawText4::createModule(outPath, v11n);
+		}
 	}
 
 	SWModule *module = 0;
@@ -206,6 +212,7 @@ int main(int argc, char **argv) {
 
 	FileMgr::getSystemFileMgr()->close(fd);
 
+	delete module;
 	delete vkey;
 
 	return 0;
