@@ -1,3 +1,24 @@
+/******************************************************************************
+ * This utility outputs a specified ordinal entry from a lex
+ *
+ * $Id: lexdump.c 2362 2009-04-29 07:21:35Z scribe $
+ *
+ * Copyright 1998-2009 CrossWire Bible Society (http://www.crosswire.org)
+ *	CrossWire Bible Society
+ *	P. O. Box 2528
+ *	Tempe, AZ  85280-2528
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the
+ * Free Software Foundation version 2.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
+ */
+
 #include <ctype.h>
 #include <stdio.h>
 #include <fcntl.h>
@@ -31,9 +52,9 @@ int main(int argc, char **argv) {
 
 	tmpbuf = calloc(strlen(argv[1]) + 11,1);
 	sprintf(tmpbuf, "%s.idx", argv[1]);
-	idxfd = open(tmpbuf, O_RDONLY|O_BINARY, S_IREAD|S_IWRITE|S_IRGRP|S_IROTH);
+	idxfd = open(tmpbuf, O_RDONLY|O_BINARY);
 	sprintf(tmpbuf, "%s.dat", argv[1]);
-	datfd = open(tmpbuf, O_RDONLY|O_BINARY, S_IREAD|S_IWRITE|S_IRGRP|S_IROTH);
+	datfd = open(tmpbuf, O_RDONLY|O_BINARY);
 	free(tmpbuf);
 
 	offset = atoi(argv[2]) * 6;
