@@ -15,6 +15,10 @@
  *
  */
 
+#ifdef _MSC_VER
+	#pragma warning( disable: 4251 )
+#endif
+
 #include <stdio.h>
 #include <rawtext.h>
 #include <swmgr.h>
@@ -22,7 +26,6 @@
 #include <markupfiltmgr.h>
 #include <swbuf.h>
 
-
 #ifndef NO_SWORD_NAMESPACE
 using sword::SWMgr;
 using sword::SWModule;
